@@ -27,6 +27,8 @@ extern void fx_head_free(FxHead* fxhead);
 
 extern void fx_head_initialize(FxMain* fxmain);
 
+extern void fx_head_show(FxMain *fxmain);
+
 extern void fx_head_bind(FxMain* fxmain);
 
 void fx_head_set_state_image(FxMain* fxmain , StateType type);
@@ -46,4 +48,6 @@ extern void fx_head_change_state_func(GtkWidget* UNUSED(widget) , gpointer data)
 extern void fx_head_change_portrait_func(GtkWidget* widget , GdkEventButton* event , gpointer data);
 
 extern void* fx_head_change_portrait_thread(void* data);
+
+extern gboolean fx_head_set_sms_clicked(GtkWidget *widget , gpointer data);
 #endif
