@@ -40,7 +40,7 @@
 #endif
 
 #define FETION_NAME "OpenFetion"
-#define FETION_VERSION "1.8"
+#define FETION_VERSION "1.9"
 #define PROTO_VERSION "4.0.2510"
 #define NAVIGATION_URI "nav.fetion.com.cn"
 #define PGGROUP_SPACE_URI "http://group.feixin.10086.cn/space/Index/"
@@ -318,9 +318,10 @@ typedef struct
 	int autoPopup;						/* whether auto pupup chat dialog enabled				  */
 	int sendMode;						/* press enter to send message or ctrl + enter 			  */
 	int closeMode;						/* close button clicked to close window or iconize it	  */
+	int canIconify;
+	int allHighlight;
 	struct userlist* ul;				/* user list stored in local data file					  */
 	Proxy *proxy;						/* structure stores the global proxy information 		  */
-	int canIconify;
 } Config;
 
 /**
@@ -351,6 +352,7 @@ typedef struct
 	char province[6];					/* the province which your number belongs to				*/
 	char city[6];						/* the city which your number belongs to 					*/
 	int gender;							/* the gender of your self									*/
+	char smsOnLineStatus[32];
 
 	int smsDayLimit;
 	int smsDayCount;
@@ -395,6 +397,8 @@ typedef struct
 	char* message;						 /* message content  		*/
 	char* sipuri;						 /* sender`s sip uri 		*/
 	char* pguri;
+	int callid;
+	int sysback;
 	struct tm sendtime;					 /* message sent time 		*/
 } Message;
 
@@ -443,4 +447,11 @@ typedef struct{
 	int outerTcpPort;
 } Share;
 
+struct unacked_list {
+	int timeout;
+	Message *message;
+	struct unacked_list *next;
+	struct unacked_list *pre;
+};
+
 #endif
