@@ -204,8 +204,7 @@ void fetion_config_download_configuration(User* user)
 	char* ip;
 	sprintf(path , "%s/configuration.xml" , user->config->userPath);
 	ip = get_ip_by_name(uri);
-	if(ip == NULL)
-	{
+	if(ip == NULL){
 		debug_error("Parse configuration uri (%s) failed!!!");
 		return;
 	}
@@ -295,38 +294,177 @@ int fetion_config_load_xml(User* user)
 	xmlFree(res);
 	return 1;
 }
-int fetion_config_load_data(User* user)
+
+int fetion_config_load_data(User *user)
 {
 	char path[256];
-	FILE *file;
-	size_t n;
-	Config config;
+	xmlDocPtr doc;
+	xmlNodePtr node;
+	xmlNodePtr pnode;
+	xmlChar *res;
+	FILE *test_fd;
 	Config *cfg = user->config;
 
-	bzero(path , sizeof(path));
-	sprintf(path , "%s/config.dat" , cfg->userPath);
 
-	file = fopen(path , "rb");
-
-	if(file == NULL)
+	memset(path , 0 , sizeof(path));
+	snprintf(path , 255 , "%s/config.xml" , cfg->userPath);
+	test_fd = fopen(path , "r");
+	if(test_fd)
+		fclose(test_fd);
+	else
+		return -1;
+	doc = xmlParseFile(path);
+	if(!doc)
 		return -1;
 
-	debug_info("Loading config data file");
-	n = fread(&config , sizeof(Config) , 1 , file);
-	if(n != 1)
-		return -1;
+	pnode = xmlDocGetRootElement(doc);
 
-	cfg->iconSize = config.iconSize;
-	cfg->autoReply = config.autoReply;
-	bzero(cfg->autoReplyMessage , sizeof(cfg->autoReplyMessage));
-	strcpy(cfg->autoReplyMessage , config.autoReplyMessage);
-	cfg->autoPopup = config.autoPopup;
-	cfg->sendMode = config.sendMode;
-	cfg->closeMode = config.closeMode;
-	cfg->iconSize = config.iconSize;
-	cfg->closeAlert = config.closeAlert;
-	cfg->msgAlert = config.msgAlert;
-	cfg->canIconify = config.canIconify;
+	node = xml_goto_node(pnode , "icon_size");
+	if(node){
+		res = xmlGetProp(node , BAD_CAST "value");
+		cfg->iconSize = atoi((char*)res);	
+		xmlFree(res);
+	}
+
+	node = xml_goto_node(pnode , "close_alert");
+	if(node){
+		res = xmlGetProp(node , BAD_CAST "value");
+		cfg->closeAlert = atoi((char*)res);	
+		xmlFree(res);
+	}
+
+	node = xml_goto_node(pnode , "auto_reply");
+	if(node){
+		res = xmlGetProp(node , BAD_CAST "value");
+		cfg->autoReply = atoi((char*)res);	
+		xmlFree(res);
+	}
+
+	node = xml_goto_node(pnode , "is_mute");
+	if(node){
+		res = xmlGetProp(node , BAD_CAST "value");
+		cfg->isMute = atoi((char*)res);	
+		xmlFree(res);
+	}
+
+	node = xml_goto_node(pnode , "message_alert");
+	if(node){
+		res = xmlGetProp(node , BAD_CAST "value");
+		cfg->msgAlert = atoi((char*)res);	
+		xmlFree(res);
+	}
+
+	node = xml_goto_node(pnode , "auto_popup");
+	if(node){
+		res = xmlGetProp(node , BAD_CAST "value");
+		cfg->autoPopup = atoi((char*)res);	
+		xmlFree(res);
+	}
+
+	node = xml_goto_node(pnode , "send_mode");
+	if(node){
+		res = xmlGetProp(node , BAD_CAST "value");
+		cfg->sendMode = atoi((char*)res);	
+		xmlFree(res);
+	}
+
+	node = xml_goto_node(pnode , "close_mode");
+	if(node){
+		res = xmlGetProp(node , BAD_CAST "value");
+		cfg->closeMode = atoi((char*)res);	
+		xmlFree(res);
+	}
+
+	node = xml_goto_node(pnode , "can_iconify");
+	if(node){
+		res = xmlGetProp(node , BAD_CAST "value");
+		cfg->canIconify = atoi((char*)res);	
+		xmlFree(res);
+	}
+
+	node = xml_goto_node(pnode , "all_highlight");
+	if(node){
+		res = xmlGetProp(node , BAD_CAST "value");
+		cfg->allHighlight = atoi((char*)res);	
+		xmlFree(res);
+	}
+
+	xmlFreeDoc(doc);
+
+	return 1;
+
+}
+
+int fetion_config_save(User* user)
+{
+	const char xml[] = "<config></config>";
+	char path[256];
+	char buffer[1024];
+	xmlDocPtr doc;
+	xmlNodePtr pnode;
+	xmlNodePtr node;
+	Config *config = user->config;
+
+	memset(path , 0 , sizeof(path));
+	snprintf(path , 255 , "%s/config.xml" , config->userPath);
+
+	debug_info("Save configration file");
+
+	doc = xmlParseMemory(xml , strlen(xml));
+	if(!doc){
+		debug_info("save configuration file failed\n");
+		return -1;
+	}
+	pnode = xmlDocGetRootElement(doc);
+	node = xmlNewChild(pnode , NULL , BAD_CAST "icon_size" , NULL);
+	sprintf(buffer , "%d" , config->iconSize);
+	xmlNewProp(node , BAD_CAST "value" , BAD_CAST buffer);
+
+	node = xmlNewChild(pnode , NULL , BAD_CAST "close_alert" , NULL);
+	sprintf(buffer , "%d" , config->closeAlert);
+	xmlNewProp(node , BAD_CAST "value" , BAD_CAST buffer);
+
+	node = xmlNewChild(pnode , NULL , BAD_CAST "auto_reply" , NULL);
+	sprintf(buffer , "%d" , config->autoReply);
+	xmlNewProp(node , BAD_CAST "value" , BAD_CAST buffer);
+
+	node = xmlNewChild(pnode , NULL , BAD_CAST "is_mute" , NULL);
+	sprintf(buffer , "%d" , config->isMute);
+	xmlNewProp(node , BAD_CAST "value" , BAD_CAST buffer);
+
+#if 0
+	node = xmlNewChild(pnode , NULL , BAD_CAST "auto_reply_message" , NULL);
+	sprintf(buffer , "%s" , config->autoReplyMessage);
+	xmlNewProp(node , BAD_CAST "value" , BAD_CAST buffer);
+#endif
+
+	node = xmlNewChild(pnode , NULL , BAD_CAST "message_alert" , NULL);
+	sprintf(buffer , "%d" , config->msgAlert);
+	xmlNewProp(node , BAD_CAST "value" , BAD_CAST buffer);
+
+	node = xmlNewChild(pnode , NULL , BAD_CAST "auto_popup" , NULL);
+	sprintf(buffer , "%d" , config->autoPopup);
+	xmlNewProp(node , BAD_CAST "value" , BAD_CAST buffer);
+
+	node = xmlNewChild(pnode , NULL , BAD_CAST "send_mode" , NULL);
+	sprintf(buffer , "%d" , config->sendMode);
+	xmlNewProp(node , BAD_CAST "value" , BAD_CAST buffer);
+
+	node = xmlNewChild(pnode , NULL , BAD_CAST "close_mode" , NULL);
+	sprintf(buffer , "%d" , config->closeMode);
+	xmlNewProp(node , BAD_CAST "value" , BAD_CAST buffer);
+
+	node = xmlNewChild(pnode , NULL , BAD_CAST "can_iconify" , NULL);
+	sprintf(buffer , "%d" , config->canIconify);
+	xmlNewProp(node , BAD_CAST "value" , BAD_CAST buffer);
+
+	node = xmlNewChild(pnode , NULL , BAD_CAST "all_highlight" , NULL);
+	sprintf(buffer , "%d" , config->allHighlight);
+	xmlNewProp(node , BAD_CAST "value" , BAD_CAST buffer);
+
+	xmlSaveFormatFile(path , doc , 0);
+	xmlFreeDoc(doc);
+	
 	return 1;
 }
 
@@ -376,25 +514,6 @@ void fetion_config_save_proxy(Proxy *proxy)
 	fclose(file);
 }
 
-int fetion_config_save(User* user)
-{
-	char path[256];
-	Config *config = user->config;
-	FILE *file;
-
-	bzero(path , sizeof(path));
-	sprintf(path , "%s/config.dat" , config->userPath);
-
-	file = fopen(path , "wb+");
-
-	debug_info("Save configration file");
-	fwrite(config , sizeof(Config) , 1 , file);
-
-	fclose(file);
-	
-	return 1;
-}
-
 char* generate_configuration_body(User* user)
 {
 	xmlChar* buf;
@@ -492,7 +611,7 @@ xmlNodePtr xml_goto_node(xmlNodePtr node , const char* name)
 		if(strcmp(name , (char*)pos->name) == 0)
 			return pos;
 		tmp = pos->xmlChildrenNode;
-		if(tmp != NULL
+		if(tmp != NULL && xmlStrcmp(tmp->name , BAD_CAST "text") != 0
 		   &&tmp->type == XML_ELEMENT_NODE
 		   && (tmp = xml_goto_node(tmp , name)) != NULL )
 			return tmp;
