@@ -77,14 +77,13 @@ char* generate_response(const char* nouce , const char* userid
 	BN_hex2bn(&bnn, modulus);
 	BN_hex2bn(&bne, exponent);
 	r->n = bnn;	r->e = bne;	r->d = NULL;
-	RSA_print_fp(stdout, r, 5);
+//	RSA_print_fp(stdout, r, 5);
 	flen = RSA_size(r);
 	out =  (unsigned char*)malloc(flen);
 	memset(out , 0 , flen);
 	debug_info("Start encrypting response");
 	ret = RSA_public_encrypt(nonce_len + aeskey_len + psd_len, res , out, r, RSA_PKCS1_PADDING);
-	if (ret < 0)
-	{
+	if (ret < 0){
 		debug_info("Encrypt response failed!");
 		return NULL;
 	}
@@ -104,20 +103,27 @@ void generate_pic_code(User* user)
 	char* ip;
 
 	FILE* picfd;
-	int piclen;
+	int piclen = 0;
 	unsigned char* pic;
 	int n;
+	Config *config = user->config;
 
 	xmlDocPtr doc;
 	xmlNodePtr node;
 
 	DEBUG_FOOTPRINT();
 
-	bzero(buf , sizeof(buf));
+	memset(buf , 0 , sizeof(buf));
 	ip = get_ip_by_name(NAVIGATION_URI);
 	FetionConnection* con = tcp_connection_new();
-	tcp_connection_connect(con , ip , 80);
-	bzero(cookie , sizeof(cookie));
+
+	if(config->proxy != NULL && config->proxy->proxyEnabled)
+		tcp_connection_connect_with_proxy(con , ip,
+				80 , config->proxy);
+	else
+		tcp_connection_connect(con , ip , 80);
+
+	memset(cookie , 0 , sizeof(cookie));
 	if(user->ssic){
 		sprintf(cookie , "Cookie: ssic=%s\r\n" , user->ssic);
 	}
@@ -268,8 +274,9 @@ char* sipc_aut_action(User* user , const char* response)
 	}
 	sipmsg = fetion_sip_to_string(sip , xml);
 	debug_info("Start sipc authentication , with ak-value");
-	debug_info("contact-version : %s , personal-version %s"
-			 , user->contactVersion , user->personalVersion);
+//	debug_info("contact-version : %s , personal-version %s"
+//			 , user->contactVersion , user->personalVersion);
+
 	tcp_connection_send(sip->tcp , sipmsg , strlen(sipmsg));
 	res = fetion_sip_get_response(sip);
 	free(sipmsg);
@@ -376,19 +383,15 @@ int parse_sipc_auth_response(const char* auth_response , User* user)
 
 	code = fetion_sip_get_code(auth_response);
 	user->loginStatus = code;
-	if(code == 200)
-	{
+
+	if(code == 200){
 		fetion_verification_free(user->verification);
 		user->verification = NULL;
 		debug_info("Sipc authentication success");
-	}
-	else if(code == 421 || code == 420)
-	{
+	}else if(code == 421 || code == 420){
 		parse_add_buddy_verification(user , auth_response);
 		return 2;
-	}
-	else
-	{
+	}else{
 		debug_error("Sipc authentication failed");
 		return -1;
 	}
@@ -536,6 +539,12 @@ static void parse_personal_info(xmlNodePtr node , User* user)
 		user->gender = atoi((char*)buf);
 		xmlFree(buf);
 	}
+	if(xmlHasProp(node , BAD_CAST "sms-online-status"))
+	{
+		buf = xmlGetProp(node , BAD_CAST "sms-online-status");
+		strcpy(user->smsOnLineStatus , (char*)buf);
+		xmlFree(buf);
+	}
 	if(xmlHasProp(node , BAD_CAST "impresa"))
 	{
 		buf = xmlGetProp(node , BAD_CAST "impresa");
@@ -567,15 +576,15 @@ static void parse_contact_list(xmlNodePtr node , User* user)
 
 	DEBUG_FOOTPRINT();
 
-	buf = xmlGetProp(node , BAD_CAST "version");
+//	buf = xmlGetProp(node , BAD_CAST "version");
 	debug_info("Start reading contact list ");
-	if(strcmp(user->contactVersion , (char*) buf) == 0){
-		debug_info("Contact list is the same as that stored in the local disk!");
-		return ;
-	}
-	strcpy(user->contactVersion , (char*)buf);
-	xmlFree(buf);
-	node1 = node->xmlChildrenNode;
+//	if(strcmp(user->contactVersion , (char*) buf) == 0){
+//		debug_info("Contact list is the same as that stored in the local disk!");
+//		return ;
+//	}
+//	strcpy(user->contactVersion , (char*)buf);
+//	xmlFree(buf);
+	node1 = xml_goto_node(node , "buddy-lists");
 	node2 = node1->xmlChildrenNode;
 	while(node2 != NULL){
 		buf = xmlGetProp(node2 , BAD_CAST "id");
@@ -592,11 +601,17 @@ static void parse_contact_list(xmlNodePtr node , User* user)
 		
 		if(hasGroup == 0){
 			fetion_group_list_append(user->groupList , group);
+			hasGroup = 1;
 		}
 		node2 = node2->next;
 	}
-	node1 = node1->next->xmlChildrenNode;
+	node1 = xml_goto_node(node , "buddies");
+	node1 = node1->xmlChildrenNode;
 	while(node1 != NULL){
+		if(! xmlHasProp(node1 , BAD_CAST "i")){
+			node1 = node1->next;
+			continue;
+		}
 		buf = xmlGetProp(node1 , BAD_CAST "i");
 		contact = fetion_contact_list_find_by_userid(user->contactList , (char*)buf);
 		if(contact == NULL){
@@ -605,31 +620,46 @@ static void parse_contact_list(xmlNodePtr node , User* user)
 		}
 		strcpy(contact->userId , (char*)buf);
 		xmlFree(buf);
-		buf = xmlGetProp(node1 , BAD_CAST "n");
-		strcpy(contact->localname , (char*)buf);
-		xmlFree(buf);
-		buf = xmlGetProp(node1 , BAD_CAST "l");
-		contact->groupid = atoi((char*)buf);
-		xmlFree(buf);
-		buf = xmlGetProp(node1 , BAD_CAST "p");
-		if(strstr((char*)buf , "identity=1") != NULL)
-			contact->identity = 1;
-		else
-			contact->identity = 0;
-		buf = xmlGetProp(node1 , BAD_CAST "r");
-		contact->relationStatus = atoi((char*)buf);
-		xmlFree(buf);
+		if(xmlHasProp(node1 , BAD_CAST "n")){
+			buf = xmlGetProp(node1 , BAD_CAST "n");
+			strcpy(contact->localname , (char*)buf);
+			xmlFree(buf);
+		}
+		if(xmlHasProp(node1 , BAD_CAST "l")){
+			buf = xmlGetProp(node1 , BAD_CAST "l");
+			contact->groupid = atoi((char*)buf);
+			if(xmlStrstr(buf , BAD_CAST ";") != NULL
+					|| contact->groupid < 0)
+					contact->groupid = 0;
+			xmlFree(buf);
+		}
+		if(xmlHasProp(node1 , BAD_CAST "p")){
+			buf = xmlGetProp(node1 , BAD_CAST "p");
+			if(strstr((char*)buf , "identity=1") != NULL)
+				contact->identity = 1;
+			else
+				contact->identity = 0;
+			xmlFree(buf);
+		}
+		if(xmlHasProp(node1 , BAD_CAST "r")){
+			buf = xmlGetProp(node1 , BAD_CAST "r");
+			contact->relationStatus = atoi((char*)buf);
+			xmlFree(buf);
+		}
 
-		buf = xmlGetProp(node1 , BAD_CAST "u");
-		strcpy(contact->sipuri , (char*)buf);
-		//if(strstr((char*)buf , "tel") != NULL)
-		//	contact->serviceStatus = STATUS_SMS_ONLINE;
-		xmlFree(buf);
+		if(xmlHasProp(node1 , BAD_CAST "u")){
+			buf = xmlGetProp(node1 , BAD_CAST "u");
+			strcpy(contact->sipuri , (char*)buf);
+			//if(strstr((char*)buf , "tel") != NULL)
+			//	contact->serviceStatus = STATUS_SMS_ONLINE;
+			xmlFree(buf);
+		}
 
 		strcpy(contact->portraitCrc , "unlogin");
 
 		if(hasBuddy == 0){
 			fetion_contact_list_append(user->contactList , contact);
+			hasBuddy = 1;
 		}
 		node1 = node1->next;
 	}
