@@ -20,6 +20,8 @@
 
 #include <openfetion.h>
 
+struct unacked_list *unackedlist;
+
 static int fetion_user_download_portrait_again(const char* filepath , const char* buf , Proxy *proxy);
 static char* generate_set_state_body(StateType state);
 static char* generate_set_moodphrase_body(const char* customConfigVersion
@@ -27,6 +29,8 @@ static char* generate_set_moodphrase_body(const char* customConfigVersion
 static char* generate_update_information_body(User* user);
 static char* generate_keep_alive_body();
 static void parse_set_moodphrase_response(User* user , const char* sipmsg);
+static char* generate_set_sms_status_body(int days);
+static void parse_set_sms_status_response(User *user , const char *sipmsg);
 
 User* fetion_user_new(const char* no , const char* password)
 {
@@ -56,6 +60,9 @@ User* fetion_user_new(const char* no , const char* password)
 	user->customConfig = NULL;
 	user->ssic = NULL;
 	user->config = NULL;
+
+	unackedlist = unacked_list_new(NULL);
+
 	return user;
 }
 
@@ -135,20 +142,15 @@ int fetion_user_set_moodphrase(User* user , const char* moodphrase)
 	res = fetion_sip_to_string(sip , body);
 	free(body);
 	tcp_connection_send(sip->tcp , res , strlen(res));
-	printf("%s\n" , res);
 	free(res) ; 
 	res = fetion_sip_get_response(sip);
 	ret = fetion_sip_get_code(res);
-	printf("%s\n" , res);
-	if(ret == 200)
-	{
+	if(ret == 200){
 		parse_set_moodphrase_response(user , res);
 		free(res);
 		debug_info("Set moodphrase success");
 		return 1;
-	}
-	else
-	{
+	}else{
 		free(res);
 		debug_error("Set moodphrase failed , errno :" , ret);
 		return -1;
@@ -172,14 +174,12 @@ int fetion_user_update_info(User* user)
 	free(res) ; 
 	res = fetion_sip_get_response(sip);
 	ret = fetion_sip_get_code(res);
-	if(ret == 200)
-	{
+
+	if(ret == 200){
 		free(res);
 		debug_info("Update information success");
 		return 1;
-	}
-	else
-	{
+	}else{
 		free(res);
 		debug_error("Update information failed , errno :" , ret);
 		return -1;
@@ -260,8 +260,7 @@ Verification* fetion_verification_new()
 }
 void fetion_verification_free(Verification* ver)
 {
-	if(ver != NULL)
-	{
+	if(ver != NULL){
 		free(ver->algorithm);
 		free(ver->type);
 		free(ver->text);
@@ -289,8 +288,7 @@ int fetion_user_upload_portrait(User* user , const char* filename)
 	FetionConnection* tcp;
 
 	ip = get_ip_by_name(server);
-	if(ip == NULL)
-	{
+	if(ip == NULL){
 		debug_error("Parse server ip address failed , %s" , server);
 		return -1;
 	}
@@ -322,8 +320,7 @@ int fetion_user_upload_portrait(User* user , const char* filename)
 
 	memset(buf , 0 , sizeof(buf));
 	int ret;
-	while((n = fread(buf , 1 , sizeof(buf) , f)))
-	{
+	while((n = fread(buf , 1 , sizeof(buf) , f))){
 		ret = tcp_connection_send(tcp , buf , n) ;
 		memset(buf , 0 , sizeof(buf));
 	}
@@ -333,21 +330,53 @@ int fetion_user_upload_portrait(User* user , const char* filename)
 	tcp_connection_recv(tcp , res , sizeof(res));
 	bzero(code , sizeof(code));
 	strncpy(code , res + 9 , 3);
-	if(strcmp(code , "200") == 0)
-	{
+	if(strcmp(code , "200") == 0){
 		debug_info("Upload portrait success");
 		return 1;
-	}
-	else
-	{
+	}else{
 		debug_error("Upload portrait failed");
 		return -1;
 	}
 }
 
+int fetion_user_set_sms_status(User *user , int days)
+{
+	FetionSip *sip = user->sip;
+	SipHeader *eheader;
+	char buffer[2048];
+	char code[16];
+	char *body;
+	char *res;
+
+	fetion_sip_set_type(sip , SIP_SERVICE);
+	eheader = fetion_sip_event_header_new(SIP_EVENT_SETUSERINFO);
+	fetion_sip_add_header(sip , eheader);
+	body = generate_set_sms_status_body(days);
+	res = fetion_sip_to_string(sip , body);
+	tcp_connection_send(sip->tcp , res , strlen(res));
+	free(res);
+	memset(buffer , 0 , sizeof(buffer));
+	tcp_connection_recv(sip->tcp , buffer , sizeof(buffer));
+
+	res = strstr(buffer , " ") + 1;
+	memset(code , 0 , sizeof(code));
+	strncpy(code , res , 3);
+	if(strcmp(code , "200") == 0){
+		parse_set_sms_status_response(user , buffer);
+		debug_info("set sms online status to %d days[%s]"
+					   	, days , user->smsOnLineStatus);
+		return 1;
+	}else{
+		debug_error("failed to set sms online status");
+		return -1;
+	}
+
+	return 1;
+}
+
 int fetion_user_download_portrait(User* user , const char* sipuri)
 {
-    	char uri[256];
+    char uri[256];
 	char *server = user->config->portraitServerName;
 	char *portraitPath = user->config->portraitServerPath;
 	sprintf(uri , "/%s/getportrait.aspx" , portraitPath);
@@ -475,6 +504,7 @@ end:
 	tcp = NULL;
 	return 0;
 }
+
 static int fetion_user_download_portrait_again(const char* filepath , const char* buf , Proxy* proxy)
 {
 	char location[1024] = { 0 };
@@ -654,11 +684,6 @@ Contact* fetion_user_parse_presence_body(const char* body , User* user)
 #if 0
 		if(xmlHasProp(cnode , BAD_CAST "sms")){
 			pos = xmlGetProp(cnode , BAD_CAST "sms");
-			if(strstr((char*)pos , "365")
-			&& currentContact->serviceStatus == BASIC_SERVICE_NORMAL
-			&& currentContact->carrierStatus == CARRIER_STATUS_NORMAL
-			&& strlen(currentContact->carrier) != 0)
-				currentContact->state = P_OFFLINE;
 			xmlFree(pos);
 		}
 #endif
@@ -850,3 +875,43 @@ static void parse_set_moodphrase_response(User* user , const char* sipmsg)
 	xmlFree(res);
 	xmlFreeDoc(doc);
 }
+
+static char* generate_set_sms_status_body(int days)
+{
+	char args[] = "<args></args>";
+	xmlChar *res;
+	xmlDocPtr doc;
+	xmlNodePtr node;
+	char status[16];
+
+	doc = xmlParseMemory(args , strlen(args));
+	node = xmlDocGetRootElement(doc);
+	node = xmlNewChild(node , NULL , BAD_CAST "userinfo" , NULL);
+	node = xmlNewChild(node , NULL , BAD_CAST "personal" , NULL);
+	memset(status , 0 , sizeof(status));
+	sprintf(status , "%d.00:00:00" , days);
+	xmlNewProp(node , BAD_CAST "sms-online-status" , BAD_CAST status);
+	xmlDocDumpMemory(doc , &res , NULL);
+	xmlFreeDoc(doc);
+	return xml_convert(res);
+}
+
+static void parse_set_sms_status_response(User *user , const char *sipmsg)
+{
+	char *pos;
+	xmlChar* res;
+	xmlDocPtr doc;
+	xmlNodePtr node;
+	pos = strstr(sipmsg , "\r\n\r\n") + 4;
+	doc = xmlParseMemory(pos , strlen(pos));
+	node = xmlDocGetRootElement(doc);
+	node = xml_goto_node(node , "personal");
+	if(!node)
+		return;
+	if(!xmlHasProp(node , BAD_CAST "sms-online-status"))
+		return;
+	res = xmlGetProp(node , BAD_CAST "sms-online-status");
+	strcpy(user->smsOnLineStatus , (char*)res);
+	xmlFree(res);
+	xmlFreeDoc(doc);
+}
