@@ -70,7 +70,7 @@ static void
 fx_bottom_on_help_clicked(GtkWidget* UNUSED(widget) , gpointer UNUSED(data))
 {
 	if(fork() == 0){
-		execlp("firefox" , "firefox" , "http://basiccoder.com/openfetion" , (char**)NULL);
+		execlp("xdg-open" , "xdg-open" , "http://basiccoder.com/openfetion" , (char**)NULL);
 	}
 }
 void fx_bottom_initialize(FxMain* fxmain)
@@ -141,6 +141,11 @@ void fx_bottom_initialize(FxMain* fxmain)
 	gtk_toolbar_append_item(GTK_TOOLBAR(fxbottom->toolbar)
 						  , NULL , _("Get help or give advice at Open Fetion homepage")
 						  , NULL , icon , G_CALLBACK(fx_bottom_on_help_clicked) , NULL);
+}
+
+void fx_bottom_show(FxMain *fxmain)
+{
+	FxBottom *fxbottom = fxmain->bottomPanel;
 	gtk_widget_show_all(fxbottom->toolbar);
 }
 
