@@ -20,6 +20,8 @@
 
 #include "fx_include.h"
 
+extern GStaticMutex mutex;
+
 FxChat* fx_chat_new(FxMain* fxmain , Conversation* conv)
 {
 	FxChat* fxchat = (FxChat*)malloc(sizeof(FxChat));
@@ -34,7 +36,8 @@ FxChat* fx_chat_new(FxMain* fxmain , Conversation* conv)
 	return fxchat;
 }
 void fx_chat_add_message(FxChat* fxchat , const char* msg 
-	, const struct tm* datetime , const int issendmsg)
+	, const struct tm* datetime , int issendmsg,
+	int issysback)
 {
 	GtkTextIter iter;
 	GtkTextBuffer* buffer;
@@ -62,6 +65,15 @@ void fx_chat_add_message(FxChat* fxchat , const char* msg
 	buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(fxchat->recv_text));
 	strftime(time , sizeof(time) , "%H:%M:%S" , datetime);
 
+	/* timeout alert msg */
+	if(issysback) {
+		snprintf(text ,1023,
+				_("The message \"%s\" sent at [%s] send failed,please resend it"),
+				time , msg);
+		fx_chat_add_information(fxchat , text);
+		return;
+	}
+
 	usid = fetion_sip_get_sid_by_sipuri(contact->sipuri);
 	if(issendmsg == 0){
 		snprintf(text , 1023 , _("%s said: (%s):\n") , contact->nickname , time);
@@ -156,8 +168,10 @@ gboolean fx_chat_focus_in_func(GtkWidget *UNUSED(widget)
 
 	DEBUG_FOOTPRINT();
 
-	if(list_empty(ctlist))
-	{
+	g_static_mutex_lock(&mutex);
+
+	if(list_empty(ctlist)){
+
 		fx_head_set_state_image(fxmain , fxmain->user->state);
 		gtk_status_icon_set_blinking(GTK_STATUS_ICON(fxmain->trayIcon) , FALSE);
 		g_signal_handler_disconnect(fxmain->trayIcon , fxmain->iconConnectId);
@@ -165,20 +179,19 @@ gboolean fx_chat_focus_in_func(GtkWidget *UNUSED(widget)
 							 , "activate"
 							 , GTK_SIGNAL_FUNC(fx_main_tray_activate_func)
 							 , fxmain);
-	}
-	else
-	{
+	}else{
 		message = (Message*)(ctlist->data);
 		sipuri = message->sipuri;
 		sid = fetion_sip_get_sid_by_sipuri(sipuri);
-		bzero(path , sizeof(path));
+		memset(path , 0 , sizeof(path));
 		sprintf(path , "%s/%s.jpg" , config->iconPath , sid);
 		free(sid);
 		pb = gdk_pixbuf_new_from_file(path , NULL);
 		if(pb == NULL)
-			pb = gdk_pixbuf_new_from_file(SKIN_DIR"user_online.png" , NULL);
+			pb = gdk_pixbuf_new_from_file(SKIN_DIR"online.svg" , NULL);
 		gtk_status_icon_set_blinking(GTK_STATUS_ICON(fxmain->trayIcon) , TRUE);
 		gtk_status_icon_set_from_pixbuf(GTK_STATUS_ICON(fxmain->trayIcon) , pb);
+		g_object_unref(pb);
 		g_signal_handler_disconnect(fxmain->trayIcon , fxmain->iconConnectId);
 		fxmain->iconConnectId = g_signal_connect(G_OBJECT(fxmain->trayIcon) 
 							 , "activate"
@@ -186,6 +199,8 @@ gboolean fx_chat_focus_in_func(GtkWidget *UNUSED(widget)
 							, fxmain);
 	}
 	fxchat->hasFocus = CHAT_DIALOG_FOCUSED;
+
+	g_static_mutex_unlock(&mutex);
 	return FALSE;
 }
 gboolean fx_chat_focus_out_func(GtkWidget *UNUSED(widget)
@@ -200,7 +215,6 @@ gboolean fx_chat_focus_out_func(GtkWidget *UNUSED(widget)
 }
 void fx_chat_bind(FxChat* fxchat)
 {
-	
 	FxMain* fxmain = fxchat->fxmain;
 	Config* config = fxmain->user->config;
 	char text[128];
@@ -217,10 +231,6 @@ void fx_chat_bind(FxChat* fxchat)
 		gtk_window_set_icon(GTK_WINDOW(fxchat->dialog) , pixbuf);
 		g_object_unref(pixbuf);
 	}
-	sprintf(text , _("Chatting with[%s]") , fxchat->conv->currentContact->nickname);
-	gtk_window_set_title(GTK_WINDOW(fxchat->dialog) , text);
-
-
 }
 
 static void fx_chat_name_box_func(GtkWidget *UNUSED(widget)
@@ -334,7 +344,7 @@ void fx_chat_initialize(FxChat* fxchat)
 
 	fxchat->headbox = gtk_table_new(2 , 10 , FALSE );
 
-	fxchat->headpix = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"fetion.png" , 40 , 40 , NULL);
+	fxchat->headpix = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"fetion.svg" , 40 , 40 , NULL);
 	gtk_window_set_icon(GTK_WINDOW(fxchat->dialog) , fxchat->headpix);
 	fxchat->headimage = gtk_image_new_from_pixbuf(fxchat->headpix);
 	gtk_table_attach(GTK_TABLE(fxchat->headbox) , fxchat->headimage
@@ -363,8 +373,9 @@ void fx_chat_initialize(FxChat* fxchat)
 								, 1 , 2 , 0 , 1 
 								, GTK_FILL , GTK_FILL , 0 , 0);
 
-
-	fxchat->impre_label = gtk_label_new(contact->impression);
+	snprintf(nametext , 510 , "%s" , contact->impression);
+	escape_impression(nametext);
+	fxchat->impre_label = gtk_label_new(nametext);
 	gtk_label_set_justify(GTK_LABEL(fxchat->impre_label) , GTK_JUSTIFY_LEFT);
 	gtk_table_attach(GTK_TABLE(fxchat->headbox) , fxchat->impre_label  
 								, 1 , 10 , 1 , 2
@@ -420,7 +431,7 @@ void fx_chat_initialize(FxChat* fxchat)
 	g_object_unref(pb);
 	fxchat->tophone = gtk_toolbar_append_element(GTK_TOOLBAR(fxchat->toolbar)
 					 	, GTK_TOOLBAR_CHILD_TOGGLEBUTTON , NULL
-						, _("Contact`s cell phone")
+						, _("Contact's cell phone")
 					       	, _("Mesage will be send to Contact's cell phone in long SMS format") 
 						, NULL , tophone_icon
 					     , G_CALLBACK(fx_chat_on_tophone_clicked)
@@ -441,9 +452,7 @@ void fx_chat_initialize(FxChat* fxchat)
 											   , fxchat );									   
 	gtk_toolbar_append_space(GTK_TOOLBAR(fxchat->toolbar));
 
-
-
-	label = gtk_label_new(_("totle 180 character,left:"));
+	label = gtk_label_new(_("total 180 character left"));
 	fxchat->countLabel = gtk_label_new("");
 	gtk_label_set_markup(GTK_LABEL(fxchat->countLabel) , _("[<span color='#0099ff'>180</span>] characters"));
 	gtk_container_add(GTK_CONTAINER(fxchat->toolbar) , label);
@@ -503,7 +512,7 @@ void fx_chat_initialize(FxChat* fxchat)
 	sprintf(portraitPath , "%s/%s.jpg" , config->iconPath , contact->sId);
 	pb = gdk_pixbuf_new_from_file_at_size(portraitPath , 140 , 140 , NULL);
 	if(pb == NULL){
-		pb = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"fetion.png" , 140 , 140 , NULL);
+		pb = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"fetion.svg" , 140 , 140 , NULL);
 	}
 	img = gtk_image_new_from_pixbuf(pb);
 	g_object_unref(pb);
@@ -520,7 +529,7 @@ void fx_chat_initialize(FxChat* fxchat)
 	sprintf(portraitPath , "%s/%s.jpg" , config->iconPath , user->sId);
 	pb = gdk_pixbuf_new_from_file_at_size(portraitPath , 140 , 140 , NULL);
 	if(pb == NULL){
-		pb = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"fetion.png" , 140 , 140 , NULL);
+		pb = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"fetion.svg" , 140 , 140 , NULL);
 	}
 	img = gtk_image_new_from_pixbuf(pb);
 	g_object_unref(pb);
@@ -549,9 +558,11 @@ void fx_chat_destroy(GtkWidget* UNUSED(widget) , gpointer data)
 
 	DEBUG_FOOTPRINT();
 
+	g_static_mutex_lock(&mutex);
 	fx_list_remove_chat_by_sipuri(fxchat->fxmain->clist
 				, fxchat->conv->currentContact->sipuri);
 	fx_chat_free(fxchat);
+	g_static_mutex_unlock(&mutex);
 
 }
 
@@ -563,7 +574,6 @@ void* fx_chat_send_message_thread(void* data)
 	char *text = NULL;
 	struct tm *now = NULL;
 	ThreadArgs *args = NULL;
-	TimeOutArgs *targs = NULL;
 	FxList *fxlist = NULL;
 
 	DEBUG_FOOTPRINT();
@@ -572,17 +582,17 @@ void* fx_chat_send_message_thread(void* data)
 	gtk_text_buffer_get_start_iter(fxchat->send_buffer , &begin);
 	gtk_text_buffer_get_end_iter(fxchat->send_buffer , &end);
 	text = gtk_text_buffer_get_text(fxchat->send_buffer , &begin , &end , TRUE);
-	if(strlen(text) == 0)
-	{
-		fx_chat_add_information(fxchat , _("Empty mesage is not allowed."));
+	if(strlen(text) == 0){
+		fx_chat_add_information(fxchat , _("Empty messages are not allowed."));
 		return NULL;
 	}
-	now = get_currenttime();
-	fx_chat_add_message(fxchat , text , now , 1);
-	gtk_text_buffer_delete(fxchat->send_buffer , &begin , &end);
 
+	now = get_currenttime();
+	fx_chat_add_message(fxchat , text , now , 1 , 0);
+	gtk_text_buffer_delete(fxchat->send_buffer , &begin , &end);
 	gdk_threads_leave();
 
+	g_static_mutex_lock(&mutex);
 	if(fetion_conversation_invite_friend(conv) > 0)
 	{
 		args = (ThreadArgs*)malloc(sizeof(ThreadArgs));
@@ -594,19 +604,11 @@ void* fx_chat_send_message_thread(void* data)
 
 		g_thread_create(fx_main_listen_thread_func , args , FALSE , NULL);
 
-		g_usleep(100);
+		//g_usleep(100);
 		fetion_conversation_send_sms(conv , text);
-
-		/**
-		 * start send keep alive message throuth chat chanel
-		 * and put the timeout information into stack
-		 */
-		debug_info("Start periodically sending keep alive request");
-		targs = timeout_args_new(fxchat->fxmain , conv->currentSip , conv->currentContact->sipuri);
-		fxlist = fx_list_new(targs);
-		fx_list_append(fxchat->fxmain->tlist , fxlist);
-		g_timeout_add_seconds(120 , (GSourceFunc)fx_main_chat_keep_alive_func , targs);
 	}
+	g_static_mutex_unlock(&mutex);
+
 	return NULL;
 }
 
@@ -633,20 +635,25 @@ void fx_chat_send_message(FxChat* fxchat)
 	if(contact == NULL)
 		return;
 
+	text = gtk_text_buffer_get_text(fxchat->send_buffer , &begin , &end , TRUE);
+	if(strlen(text) == 0)
+		return;
+
+
 	/**
 	 * check whether 'send to phone' button is clicked ,
 	 * if true , just send to phone and return
 	 */
-	if(fxchat->sendtophone == TRUE)
-	{
+	if(fxchat->sendtophone == TRUE)	{
 		/***
 		 * show message sent,and truncate the send text area
 		 */
 		text = gtk_text_buffer_get_text(fxchat->send_buffer , &begin , &end , TRUE);
 		if(strlen(text) == 0){
-			fx_chat_add_information(fxchat , _("Empty mesage is not allowed."));
+			fx_chat_add_information(fxchat , _("Empty messages are not allowed."));
 			return;
 		}
+
 		if(user->boundToMobile == BOUND_MOBILE_DISABLE){
 
 			user->verification = fetion_verification_new();
@@ -654,10 +661,13 @@ send:
 			generate_pic_code(user);
 			bzero(reason , sizeof(reason));
 			if(user->smsDayLimit == user->smsDayCount){
-				fx_chat_add_information(fxchat , _("Sorry, you reached quota of free SMS,can't send SMS,today"));
+				fx_chat_add_information(fxchat , _("Sorry, you have reached"
+										" the quota of free SMS today, SMS"
+										" messages cannot be sent any more today."));
 				return;
 			}
-			sprintf(reason , _("You have %d free SMS can send (include this one).Free SMS: %d per month")
+			sprintf(reason , _("You have %d free SMS can send "
+					" (include this one). Free SMS: %d per month")
 					, user->smsDayLimit - user->smsMonthCount
 					, user->smsMonthLimit );
 			bzero(tips , sizeof(tips));
@@ -688,13 +698,14 @@ send:
 					, text , &daycount , &monthcount);
 		}
 		now = get_currenttime();
-		fx_chat_add_message(fxchat , text , now , 1);
+		fx_chat_add_message(fxchat , text , now , 1 , 0);
 
-		bzero(tips , sizeof(tips));
-		sprintf(tips , _("Send sucessfully. You have send %d SMS, %d left.")
+		memset(tips , 0 , sizeof(tips));
+		sprintf(tips , _("Message sent successfully. You have sent %d SMS, and %d left.")
 				, daycount , user->smsDayLimit - daycount);
 		fx_chat_add_information(fxchat , tips);
 		gtk_text_buffer_delete(fxchat->send_buffer , &begin , &end);
+
 		return;
 	}
 	/**
@@ -716,12 +727,9 @@ send:
 	/***
 	 * show message sent,and truncate the send text area
 	 */
-	text = gtk_text_buffer_get_text(fxchat->send_buffer , &begin , &end , TRUE);
-	if(strlen(text) == 0)
-		return;
 
 	now = get_currenttime();
-	fx_chat_add_message(fxchat , text , now , 1);
+	fx_chat_add_message(fxchat , text , now , 1 , 0);
 
 	gtk_text_buffer_delete(fxchat->send_buffer , &begin , &end);
 
@@ -733,13 +741,12 @@ void* fx_chat_send_nudge_thread(void* data)
 	FxChat *fxchat = (FxChat*)data;
 	Conversation *conv = fxchat->conv;
 	ThreadArgs *args = NULL;
-	TimeOutArgs *targs = NULL;
 	FxList *fxlist = NULL;
 
 	DEBUG_FOOTPRINT();
-	if(fetion_conversation_invite_friend(conv) > 0)
-	{
-		gdk_threads_enter();
+	g_static_mutex_lock(&mutex);
+	if(fetion_conversation_invite_friend(conv) > 0){
+
 		args = (ThreadArgs*)malloc(sizeof(ThreadArgs));
 		args->fxmain = fxchat->fxmain;
 		args->sip = conv->currentSip;
@@ -747,19 +754,14 @@ void* fx_chat_send_nudge_thread(void* data)
 		fxlist = fx_list_new(conv->currentSip);
 		fx_list_append(fxchat->fxmain->slist , fxlist);
 
+		gdk_threads_enter();
+
 		g_thread_create(fx_main_listen_thread_func , args , FALSE , NULL);
 		fetion_conversation_send_nudge(conv);
+
 		gdk_threads_leave();
-		/**
-		 * start send keep alive message throuth chat chanel
-		 * and put the timeout information into stack
-		 */
-		targs = timeout_args_new(fxchat->fxmain , conv->currentSip , conv->currentContact->sipuri);
-		fxlist = fx_list_new(targs);
-		fx_list_append(fxchat->fxmain->tlist , fxlist);
-		debug_info("Start periodically sending keep alive request");
-		g_timeout_add_seconds(120 , (GSourceFunc)fx_main_chat_keep_alive_func , targs);
 	}
+	g_static_mutex_unlock(&mutex);
 	return NULL;
 }
 void fx_chat_on_nudge_clicked(GtkWidget* UNUSED(widget) , gpointer data)
@@ -771,7 +773,7 @@ void fx_chat_on_nudge_clicked(GtkWidget* UNUSED(widget) , gpointer data)
 	DEBUG_FOOTPRINT();
 
 	if(contact->state <= 0){
-		fx_chat_add_information(fxchat , _("Contact is not online.Cannot send screen jitter"));
+		fx_chat_add_information(fxchat , _("Contact is not online. Cannot send screen jitter"));
 		return;
 	}
 
@@ -854,21 +856,21 @@ void fx_chat_on_tophone_clicked(GtkWidget* widget , gpointer data)
  						"more free SMS, bind you cell phone number."));
 				gtk_widget_set_sensitive(fxchat->send_text , FALSE);
 			}else{
-				sprintf(text , _("Mesage will be send toMesage will be send to contact's cell phone. You have %d free SMS left. "
+				sprintf(text , _("Mesage will be sent to contact's cell phone. You have %d free SMS left. "
 						"If want to send more free SMS, bind your cell phone,please.") 
 						, user->smsDayLimit - user->smsDayCount);
 			}
 			fx_chat_add_information(fxchat , text);
 		}else{
-			sprintf(text , _("Mesage will be seed to you phone as long SMS."
-						" You have seed %d, and %d left.")
+			sprintf(text , _("Mesage will be sent to you phone as long SMS."
+						" You have sent %d, and %d left.")
 					, user->smsDayCount , user->smsDayLimit - user->smsDayCount);
 			fx_chat_add_information(fxchat , text);
 		}
 	}else{
 		fxchat->sendtophone = FALSE;
 		gtk_widget_set_sensitive(fxchat->send_text , TRUE);
-		fx_chat_add_information(fxchat , _("Mesage will be send to contact's fetion"));
+		fx_chat_add_information(fxchat , _("Message will be sent to contact's fetion"));
 	}
 }
 void fx_chat_on_close_clicked(GtkWidget* UNUSED(widget) , gpointer data)
@@ -884,6 +886,7 @@ void fx_chat_on_send_clicked(GtkWidget* UNUSED(widget) , gpointer data)
 {
 	DEBUG_FOOTPRINT();
 
+
 	fx_chat_send_message((FxChat*)data);
 }
 void fx_chat_on_history_clicked(GtkWidget* UNUSED(widget) , gpointer data)
@@ -905,19 +908,22 @@ void fx_chat_on_history_clicked(GtkWidget* UNUSED(widget) , gpointer data)
 gboolean fx_chat_on_key_pressed(GtkWidget* UNUSED(widget)
 		, GdkEventKey* event , gpointer data)
 {
-
 	FxChat *fxchat = NULL;
 	Config *config = NULL;
 
 	DEBUG_FOOTPRINT();
 
-	if(event->keyval == GDK_Return){
+	if(event->keyval == GDK_Return || event->keyval == GDK_ISO_Enter || event->keyval == GDK_KP_Enter){
 		fxchat = (FxChat*)data;
 		config = fxchat->fxmain->user->config;
 		if(config->sendMode == SEND_MODE_ENTER){
-			if(event->state & GDK_CONTROL_MASK){
+			if(event->state & GDK_CONTROL_MASK || event->state & GDK_SHIFT_MASK){
 				return FALSE;
 			}else{
+ 				if (gtk_im_context_filter_keypress (GTK_TEXT_VIEW(fxchat->send_text)->im_context, event)) {
+					GTK_TEXT_VIEW (fxchat->send_text)->need_im_reset = TRUE;
+ 					return TRUE;
+ 				}
 				fx_chat_send_message(fxchat);
 				return TRUE;
 			}
