@@ -55,8 +55,9 @@ void fx_close_initialize(FxClose *fxclose)
 	
 	fxclose->dialog = gtk_dialog_new();
 	gtk_window_set_title(GTK_WINDOW(fxclose->dialog) , _("Notification"));
-	pb = gdk_pixbuf_new_from_file(SKIN_DIR"user_online.png" , NULL);
+	pb = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"online.svg" , 22 , 22 , NULL);
 	gtk_window_set_icon(GTK_WINDOW(fxclose->dialog) , pb);
+	g_object_unref(pb);
 	gtk_widget_set_usize(fxclose->dialog , 280 , 180);
 	gtk_window_set_resizable(GTK_WINDOW(fxclose->dialog) , FALSE);
 
@@ -65,10 +66,10 @@ void fx_close_initialize(FxClose *fxclose)
 	fixed = GTK_FIXED(gtk_fixed_new());
 	gtk_box_pack_start_defaults(vbox , GTK_WIDGET(fixed));
 
-	label = gtk_label_new(_("Are you sure to exit OpenFetion ?"));
+	label = gtk_label_new(_("Are you sure you want to quit OpenFetion?"));
 	gtk_fixed_put(fixed , label , 20 , 20);
 
-	fxclose->closeBtn = gtk_radio_button_new_with_label(NULL , _("Exit Openfetion"));
+	fxclose->closeBtn = gtk_radio_button_new_with_label(NULL , _("Exit OpenFetion"));
 	group = gtk_radio_button_get_group(GTK_RADIO_BUTTON(fxclose->closeBtn));
 	fxclose->iconBtn = gtk_radio_button_new_with_label(group , _("Minimize to tray"));
 	fxclose->notalert = gtk_check_button_new_with_label(_("Don't notify again"));
@@ -84,6 +85,9 @@ void fx_close_initialize(FxClose *fxclose)
 	gtk_box_pack_start_defaults(action_area , okBtn);
 	gtk_box_pack_start_defaults(action_area , cancelBtn);
 
+	GTK_WIDGET_SET_FLAGS(okBtn, GTK_CAN_FOCUS);
+	gtk_widget_grab_focus(okBtn);
+
 	gtk_widget_show_all(fxclose->dialog);
 	gtk_widget_hide(fxclose->dialog);
 }
