@@ -50,14 +50,15 @@ void fx_code_initialize(FxCode *fxcode)
 
 	fxcode->dialog = gtk_dialog_new();
 	gtk_window_set_title(GTK_WINDOW(fxcode->dialog) , _("Please entry your verification code"));
-	icon = gdk_pixbuf_new_from_file(SKIN_DIR"warning.png" , NULL);
+	icon = gdk_pixbuf_new_from_file(SKIN_DIR"warning.svg" , NULL);
 	gtk_window_set_icon(GTK_WINDOW(fxcode->dialog) , icon);
 	vbox = GTK_DIALOG(fxcode->dialog)->vbox;
 	action_area = GTK_DIALOG(fxcode->dialog)->action_area;
 	fixed = gtk_fixed_new();
 	gtk_widget_set_usize(fxcode->dialog , 460 , 250);
-	pb = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"warning_icon.png" , 96 , 96 , NULL);
+	pb = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"warning.svg" , 96 , 96 , NULL);
 	warningpic = gtk_image_new_from_pixbuf(pb);
+	g_object_unref(pb);
 	gtk_fixed_put(GTK_FIXED(fixed) , warningpic , 20 , 20 );
 	
 	fxcode->reasonlabel = gtk_label_new(fxcode->reason);
@@ -69,11 +70,13 @@ void fx_code_initialize(FxCode *fxcode)
 	fxcode->codeentry = gtk_entry_new();
 	gtk_widget_set_usize(fxcode->codeentry , 300 , 30);
 	gtk_fixed_put(GTK_FIXED(fixed)  , fxcode->codeentry , 150 , 70);
+	g_signal_connect(fxcode->codeentry, "key_press_event" , G_CALLBACK(fx_code_on_key_pressed), fxcode);
 
-	bzero(codePath , sizeof(codePath));
+	memset(codePath , 0 , sizeof(codePath));
 	sprintf(codePath , "%s/code.gif" , fxcode->fxmain->user->config->globalPath);
 	pb = gdk_pixbuf_new_from_file_at_size(codePath , 130 , 36 , NULL);
 	fxcode->codepic = gtk_image_new_from_pixbuf(pb);
+	g_object_unref(pb);
 	gtk_widget_set_tooltip_markup(fxcode->codepic , _("Click here getting new verification code"));
 	fxcode->codebox = gtk_event_box_new();
 	g_signal_connect(G_OBJECT(fxcode->codebox)
@@ -99,6 +102,8 @@ void fx_code_initialize(FxCode *fxcode)
 	gtk_fixed_put(GTK_FIXED(fixed) , fxcode->tiplabel , 20 , 160);
 
 	ok_button = gtk_button_new_with_label(_("OK"));
+	GTK_WIDGET_SET_FLAGS(ok_button , GTK_CAN_FOCUS);
+	gtk_widget_grab_focus(ok_button);
 	g_signal_connect(ok_button , "clicked" , G_CALLBACK(fx_code_on_ok_clicked) , fxcode->dialog);
 	gtk_box_pack_start_defaults(GTK_BOX(action_area) , ok_button);
 
@@ -110,6 +115,7 @@ void fx_code_initialize(FxCode *fxcode)
 	gtk_widget_show_all(fxcode->dialog);
 	gtk_widget_hide(fxcode->dialog);
 }
+
 void fx_code_code_event_func(GtkWidget* UNUSED(widget) , GdkEventButton* event , gpointer data)
 {
 	FxCode *fxcode = (FxCode*)data;
@@ -128,6 +134,7 @@ void fx_code_code_event_func(GtkWidget* UNUSED(widget) , GdkEventButton* event ,
 			sprintf(codePath , "%s/code.gif" , fxcode->fxmain->user->config->globalPath);
 			pb = gdk_pixbuf_new_from_file_at_size(codePath , 130 , 36 , NULL);
 			gtk_image_set_from_pixbuf(GTK_IMAGE(fxcode->codepic) , pb);
+			g_object_unref(pb);
 			break;
 		case GDK_ENTER_NOTIFY :
 			cursor = gdk_cursor_new (GDK_HAND2);
@@ -141,6 +148,7 @@ void fx_code_code_event_func(GtkWidget* UNUSED(widget) , GdkEventButton* event ,
 			break;
 	};
 }
+
 void fx_code_on_ok_clicked(GtkWidget* UNUSED(widget) , gpointer data)
 {
 	DEBUG_FOOTPRINT();
@@ -154,3 +162,15 @@ void fx_code_on_cancel_clicked(GtkWidget* UNUSED(widget) , gpointer data)
 
 	gtk_dialog_response(GTK_DIALOG(data) , GTK_RESPONSE_CANCEL);
 }
+
+gboolean fx_code_on_key_pressed(GtkWidget* UNUSED(widget), GdkEventKey* event, gpointer data)
+{
+	FxCode *fxcode = (FxCode*)data;
+
+	if(event->keyval == GDK_Return || event->keyval == GDK_ISO_Enter || event->keyval == GDK_KP_Enter)
+	{
+		fx_code_on_ok_clicked(NULL, fxcode->dialog);
+		return TRUE;
+	}
+	return FALSE;
+}
