@@ -20,6 +20,9 @@
 
 #include "fx_include.h"
 
+static gboolean key_press_func(GtkWidget *UNUSED(widget) , GdkEventKey *event
+		, gpointer data);
+
 FxConfirm* fx_confirm_new(FxMain *fxmain)
 {
 	FxConfirm *fxconfirm ;
@@ -56,21 +59,22 @@ void fx_confirm_initialize(FxConfirm *fxconfirm)
 	fxconfirm->dialog = gtk_dialog_new();
 	gtk_widget_set_usize(fxconfirm->dialog , 420 , 220);
 	gtk_window_set_resizable(GTK_WINDOW(fxconfirm->dialog) , FALSE);
-	pb = gdk_pixbuf_new_from_file(SKIN_DIR"user_online.png" , NULL);
+	pb = gdk_pixbuf_new_from_file(SKIN_DIR"online.svg" , NULL);
 	gtk_window_set_icon(GTK_WINDOW(fxconfirm->dialog) , pb);
+	g_object_unref(pb);
 	gtk_window_set_title(GTK_WINDOW(fxconfirm->dialog) , ("SMS directly"));
 
 	fixed = gtk_fixed_new();
 	gtk_box_pack_start_defaults(GTK_BOX(GTK_DIALOG(fxconfirm->dialog)->vbox)
 			, fixed);
-	infoLabel = gtk_label_new(_("Fetion has send verification code as SMS to your cell phone. Please input it."));
+	infoLabel = gtk_label_new(_("Fetion has sent the verification code as SMS to your cell phone. Please input it."));
 	codeLabel = gtk_label_new(_("Verification code"));
 	fxconfirm->codeEntry = gtk_entry_new();
 	gtk_widget_set_usize(fxconfirm->codeEntry , 240 , 25);
 	noteLabel = gtk_label_new(NULL);
 	gtk_label_set_markup(GTK_LABEL(noteLabel)
-			, _("<span color='#808080'>NOTE：A little timelag because of network reason"
-			 "，Please Wait......</span>"));
+			, _("<span color='#808080'>NOTE：A little timelag because of some network reason"
+			 ",Please Wait......</span>"));
 	gtk_fixed_put(GTK_FIXED(fixed) , infoLabel , 40 , 40);
 	gtk_fixed_put(GTK_FIXED(fixed) , codeLabel , 40 , 74);
 	gtk_fixed_put(GTK_FIXED(fixed) , fxconfirm->codeEntry , 120 , 70);
@@ -115,7 +119,8 @@ add_contact(gpointer data)
 
 	gtk_widget_show(fxdsms->chooseList);
 	gtk_widget_hide(fxdsms->msgLabel);
-	pb = gdk_pixbuf_new_from_file(SKIN_DIR"user_online.png" , NULL);
+	pb = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"online.svg",
+				   22 , 22 , NULL);
 	number = gtk_entry_get_text(GTK_ENTRY(fxdsms->numberEntry));
 	if(strlen(number) == 0)
 		return;
@@ -123,6 +128,7 @@ add_contact(gpointer data)
 	gtk_tree_store_set(GTK_TREE_STORE(model) , &iter
 			, PIXBUF_COL , pb , NUMBER_COL , number , -1);
 	gtk_entry_set_text(GTK_ENTRY(fxdsms->numberEntry) , "");
+	g_object_unref(pb);
 }
 
 static gboolean
@@ -380,7 +386,7 @@ picreload:
 					ret2 = gtk_dialog_run(GTK_DIALOG(fxconfirm->dialog));
 					if(ret2 == GTK_RESPONSE_CANCEL){
 						bzero(text , sizeof(text));
-						strcpy(text , _("Mesage send failed"));
+						strcpy(text , _("Message sent failed"));
 						fx_dsms_add_information(fxdsms , text);
 						gtk_widget_destroy(fxconfirm->dialog);
 						gdk_threads_leave();
@@ -482,15 +488,19 @@ fx_dsms_on_key_pressed(GtkWidget *UNUSED(widget) , GdkEventKey *event , gpointer
 
 	DEBUG_FOOTPRINT();
 
-	if(event->keyval == GDK_Return)
+	if(event->keyval == GDK_Return || event->keyval == GDK_ISO_Enter || event->keyval == GDK_KP_Enter)
 	{
 		fxdsms = (FxDSMS*)data;
 		config = fxdsms->fxmain->user->config;
 		if(config->sendMode == SEND_MODE_ENTER)
 		{
-			if(event->state & GDK_CONTROL_MASK){
+			if(event->state & GDK_CONTROL_MASK || event->state & GDK_SHIFT_MASK){
 				return FALSE;
 			}else{
+ 				if (gtk_im_context_filter_keypress (GTK_TEXT_VIEW(fxdsms->sendText)->im_context, event)) {
+					GTK_TEXT_VIEW (fxdsms->sendText)->need_im_reset = TRUE;
+ 					return TRUE;
+ 				}
 				fx_dsms_send_message(fxdsms);
 				return TRUE;
 			}
@@ -543,7 +553,10 @@ void fx_dsms_initialize(FxDSMS *fxdsms)
 	gtk_window_set_resizable(GTK_WINDOW(fxdsms->dialog) , FALSE);
 	pb = gdk_pixbuf_new_from_file(SKIN_DIR"directsms.png" , NULL);
 	gtk_window_set_icon(GTK_WINDOW(fxdsms->dialog) , pb);
+	g_object_unref(pb);
 	gtk_window_set_title(GTK_WINDOW(fxdsms->dialog) , _("SMS directly"));
+	g_signal_connect(fxdsms->dialog , "key-press-event"
+			, G_CALLBACK(key_press_func) , fxdsms);
 
 	infoLabel = gtk_label_new(NULL);
 	gtk_label_set_markup(GTK_LABEL(infoLabel)
@@ -647,6 +660,7 @@ void fx_dsms_initialize(FxDSMS *fxdsms)
 	sprintf(path , "%s/%s.jpg" , config->iconPath , user->sId);
 	pb = gdk_pixbuf_new_from_file_at_size(path , 140 , 140 , NULL);
 	portrait = gtk_image_new_from_pixbuf(pb);
+	g_object_unref(pb);
 	gtk_container_add(GTK_CONTAINER(portraitFrame) , portrait);
 	gtk_box_pack_start(GTK_BOX(rvbox) , portraitFrame , FALSE , FALSE , 2);
 	/* bottom box */
@@ -681,3 +695,20 @@ void fx_dsms_initialize(FxDSMS *fxdsms)
 	gtk_widget_show_all(fxdsms->dialog);
 	gtk_widget_hide(fxdsms->chooseList);
 }
+
+static gboolean key_press_func(GtkWidget *UNUSED(widget) , GdkEventKey *event
+		, gpointer data)
+{
+	FxDSMS *fxdsms ;
+	if(event->keyval == GDK_w){
+		if(event->state & GDK_CONTROL_MASK){
+			fxdsms = (FxDSMS*)data;
+			gtk_widget_destroy(fxdsms->dialog);
+			return TRUE;
+		}else{
+			return FALSE;
+		}
+	}
+
+	return FALSE;
+}
