@@ -20,6 +20,7 @@
 
 #include "fx_include.h"
 
+
 FxHead* fx_head_new()
 {
 	FxHead* fxhead = (FxHead*)malloc(sizeof(FxHead));
@@ -51,11 +52,17 @@ void fx_head_initialize(FxMain* fxmain)
 	
 	DEBUG_FOOTPRINT();
 
-	pb = gdk_pixbuf_new_from_file_at_scale(SKIN_DIR"fetion.png" , 50 , 50 , TRUE , NULL);
+	pb = gdk_pixbuf_new_from_file_at_scale(SKIN_DIR"fetion.svg" , 50 , 50 , TRUE , NULL);
 	fxhead->portrait = gtk_image_new_from_pixbuf(pb);
+	g_object_unref(pb);
+
+	GtkWidget *frame;
+	frame = gtk_frame_new(NULL);
+	gtk_widget_set_usize(frame , 55 , 55);
 	fxhead->portraitbox = gtk_event_box_new();
 	gtk_container_add(GTK_CONTAINER(fxhead->portraitbox) , fxhead->portrait);
-	gtk_box_pack_start(GTK_BOX(hbox) , fxhead->portraitbox , FALSE , FALSE , 10 );
+	gtk_container_add(GTK_CONTAINER(frame) , fxhead->portraitbox);
+	gtk_box_pack_start(GTK_BOX(hbox) , frame , FALSE , FALSE , 10 );
 
 	g_signal_connect(G_OBJECT(fxhead->portraitbox)
 				   , "button_press_event"
@@ -77,8 +84,9 @@ void fx_head_initialize(FxMain* fxmain)
 	headbox = gtk_hbox_new(FALSE , 0);
 
 	fxhead->state_button = gtk_event_box_new();
-	pb = gdk_pixbuf_new_from_file(SKIN_DIR"user_online.png" , FALSE);
+	pb = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"online.svg" , 20 , 20 , FALSE);
 	fxhead->state_img = gtk_image_new_from_pixbuf(pb);
+	g_object_unref(pb);
 	gtk_container_add(GTK_CONTAINER(fxhead->state_button) , fxhead->state_img);
 	gtk_widget_set_events(fxhead->state_button
 						, GDK_MOTION_NOTIFY
@@ -90,6 +98,19 @@ void fx_head_initialize(FxMain* fxmain)
 					 , "button_press_event"
 					 , GTK_SIGNAL_FUNC(fx_head_popup_statemenu_func)
 					 , fxmain);
+	g_signal_connect(G_OBJECT(fxhead->state_button)
+					 , "enter_notify_event"
+					 , GTK_SIGNAL_FUNC(fx_head_popup_statemenu_func)
+					 , fxmain);
+	g_signal_connect(G_OBJECT(fxhead->state_button)
+					 , "leave_notify_event"
+					 , GTK_SIGNAL_FUNC(fx_head_popup_statemenu_func)
+					 , fxmain);
+
+	g_signal_connect(G_OBJECT(fxhead->portraitbox)
+				   , "leave_notify_event"
+				   , GTK_SIGNAL_FUNC(fx_head_change_portrait_func)
+				   , fxmain);
 
 	gtk_box_pack_start(GTK_BOX(headbox) , fxhead->state_button , TRUE , TRUE , 0);
 
@@ -125,8 +146,8 @@ void fx_head_initialize(FxMain* fxmain)
 				   , G_CALLBACK(fx_head_impre_activate_func)
 				   , fxmain);
 	fxhead->impre_label = gtk_label_new(NULL);
+	gtk_label_set_width_chars(GTK_LABEL(fxhead->impre_label) , 15);
 	gtk_misc_set_alignment(GTK_MISC(fxhead->impre_label) , 0 , 0);
-	gtk_widget_set_usize(fxhead->impre_label , 180 , 0);
 
 	alignment = gtk_alignment_new(0 , 0 , 0 , 0);
 	gtk_container_add(GTK_CONTAINER(alignment) , headbox);
@@ -141,9 +162,15 @@ void fx_head_initialize(FxMain* fxmain)
 	gtk_box_pack_start(GTK_BOX(fxhead->topbox) , halign , FALSE , FALSE , 0);
 	gtk_box_pack_start(GTK_BOX(fxmain->mainbox) , fxhead->topbox , FALSE , FALSE , 10);
 	fx_head_bind(fxmain);	
+}
+
+void fx_head_show(FxMain *fxmain)
+{
+	FxHead *fxhead = fxmain->headPanel;
 	gtk_widget_show_all(fxhead->topbox);
 	gtk_widget_hide(fxhead->impre_entry);
 }
+
 void fx_head_bind(FxMain* fxmain)
 {
 	FxHead* fxhead = fxmain->headPanel;
@@ -163,14 +190,17 @@ void fx_head_bind(FxMain* fxmain)
 			, user->nickname == NULL ? user->sId : user->nickname );
 
 	gtk_label_set_markup(GTK_LABEL(fxhead->name_label) , name );
+	
 
 	strcpy(fxhead->oldimpression
 		, (strlen(user->impression) == 0 || user->impression == NULL)
 		? "Click here to input signature" : user->impression);
-	bzero(tooltip , sizeof(tooltip));
+
+	memset(tooltip , 0 , sizeof(tooltip));
 	sprintf(tooltip , "<b>%s</b>" , user->impression);
 	gtk_widget_set_tooltip_markup(fxhead->impre_label
 			, tooltip);
+	escape_impression(fxhead->oldimpression);
 	gtk_label_set_text(GTK_LABEL(fxhead->impre_label) , fxhead->oldimpression);
 
 	bzero(name , sizeof(name));
@@ -193,6 +223,7 @@ void fx_head_bind(FxMain* fxmain)
 void fx_head_set_state_image(FxMain* fxmain , StateType type)
 {
 	FxHead* fxhead = fxmain->headPanel;
+	GdkPixbuf *pixbuf;
 	char* statename = fx_util_get_state_name(type);
 
 	DEBUG_FOOTPRINT();
@@ -201,41 +232,55 @@ void fx_head_set_state_image(FxMain* fxmain , StateType type)
 	switch(type)
 	{
 		case P_ONLINE :
-			gtk_image_set_from_file(GTK_IMAGE(fxhead->state_img)
-								  , SKIN_DIR"user_online.png");
+			pixbuf = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"online.svg" , 20 , 20 , NULL);
 			gtk_status_icon_set_from_file(fxmain->trayIcon
-										, SKIN_DIR"online_big.png");
+										, SKIN_DIR"online.svg");
 			break;
 		case P_BUSY :
-			gtk_image_set_from_file(GTK_IMAGE(fxhead->state_img)
-					              , SKIN_DIR"user_busy.png");
+			pixbuf = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"busy.svg" , 20 , 20 , NULL);
 			gtk_status_icon_set_from_file(fxmain->trayIcon
-										, SKIN_DIR"busy_big.png");
+										, SKIN_DIR"busy.svg");
 			break;
 		case P_HIDDEN :
-			gtk_image_set_from_file(GTK_IMAGE(fxhead->state_img)
-								  , SKIN_DIR"user_invisible.png");
+			pixbuf = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"invisible.svg" , 20 , 20 , NULL);
 			gtk_status_icon_set_from_file(fxmain->trayIcon
-										, SKIN_DIR"invisible_big.png");
+										, SKIN_DIR"invisible.svg");
 			break;
 		default :
-			gtk_image_set_from_file(GTK_IMAGE(fxhead->state_img)
-								  , SKIN_DIR"user_away.png");
+			pixbuf = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"away.svg" , 20 , 20 , NULL);
 			gtk_status_icon_set_from_file(fxmain->trayIcon
-										, SKIN_DIR"away_big.png");
+										, SKIN_DIR"away.svg");
 			break;
 	}
+	gtk_image_set_from_pixbuf(GTK_IMAGE(fxhead->state_img) , pixbuf);
+	g_object_unref(pixbuf);
 	free(statename);
 }
-void fx_head_popup_statemenu_func(GtkWidget* UNUSED(widget)
+void fx_head_popup_statemenu_func(GtkWidget* widget
 		, GdkEventButton* event , gpointer data)
 {
 	FxMain* fxmain = (FxMain*)data;
-	GtkWidget* separator;
-	GtkWidget* presence_menu = gtk_menu_new();
+	User *user = fxmain->user;
+	GtkWidget *item;
+	GtkWidget *img;
+	GtkWidget *separator;
+	GdkCursor *cursor;
+	GtkWidget *presence_menu = gtk_menu_new();
 
 	DEBUG_FOOTPRINT();
 
+	if(event->type == GDK_ENTER_NOTIFY) {
+		cursor = gdk_cursor_new (GDK_HAND2);
+		gdk_window_set_cursor(widget->window , cursor);
+		return;
+	}
+
+	if(event->type == GDK_LEAVE_NOTIFY)	{
+		cursor = gdk_cursor_new (GDK_LEFT_PTR);
+		gdk_window_set_cursor(widget->window , cursor);
+		return;
+	}
+
 	fx_head_create_presence_item(P_ONLINE , _("Online") , presence_menu , fxmain);
 	fx_head_create_presence_item(P_AWAY   , _("Leave") , presence_menu , fxmain);
 	fx_head_create_presence_item(P_BUSY   , _("Busy") , presence_menu , fxmain);
@@ -249,6 +294,31 @@ void fx_head_popup_statemenu_func(GtkWidget* UNUSED(widget)
 	fx_head_create_presence_item(P_MEETING      , _("Meeting") , presence_menu , fxmain);
 	fx_head_create_presence_item(P_ONTHEPHONE   , _("Calling") , presence_menu , fxmain);
 
+	separator = gtk_separator_menu_item_new();
+	gtk_menu_shell_append(GTK_MENU_SHELL(presence_menu) , separator);
+
+	item = gtk_check_menu_item_new_with_label(_("Receive SMS"));
+	if(strcmp(user->smsOnLineStatus , "0.00:00:00") &&
+		strcmp(user->smsOnLineStatus , "0.0:0:0"))
+		gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item) , FALSE);
+	else
+		gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item) , TRUE);
+	gtk_menu_shell_append(GTK_MENU_SHELL(presence_menu) , item);
+	g_signal_connect(item , "activate" , G_CALLBACK(fx_head_set_sms_clicked) , fxmain);
+
+	item = gtk_image_menu_item_new_with_label(_("Modify Profile"));
+	img = gtk_image_new_from_file(SKIN_DIR"edit.png");
+	gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(item) , img);
+	gtk_menu_shell_append(GTK_MENU_SHELL(presence_menu) , item);
+	g_signal_connect(item , "activate" , G_CALLBACK(fx_bottom_on_setting_clicked) , fxmain);
+
+	item = gtk_image_menu_item_new_with_label(_("Exit OpenFetion "));
+	img = gtk_image_new_from_file(SKIN_DIR"exit.png");
+	gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(item) , img);
+	gtk_menu_shell_append(GTK_MENU_SHELL(presence_menu) , item);
+	g_signal_connect(item , "activate" , G_CALLBACK(fx_main_destroy) , fxmain);
+
+
 	gtk_widget_show_all(presence_menu);
 	
 	gtk_menu_popup(GTK_MENU(presence_menu) , NULL , NULL , NULL , NULL 
@@ -263,6 +333,7 @@ void fx_head_create_presence_item(int type , const char* message , GtkWidget* me
 	} Args;
 	GtkWidget* item = gtk_image_menu_item_new_with_label(message);
 	GtkWidget* item_img = NULL;
+	GdkPixbuf *pixbuf;
 	Args *args = (Args*)malloc(sizeof(Args));
 	args->fxmain = fxmain;
 	args->type = type;
@@ -270,25 +341,30 @@ void fx_head_create_presence_item(int type , const char* message , GtkWidget* me
 	switch(type)
 	{
 		case P_ONLINE :
-			item_img = gtk_image_new_from_file(SKIN_DIR"user_online.png");
+			pixbuf = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"online.svg" , 20 , 20 , NULL);
 			break;
 		case P_BUSY :
-			item_img = gtk_image_new_from_file(SKIN_DIR"user_busy.png");
+			pixbuf = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"busy.svg" , 20 , 20 , NULL);
 			break;
 		case P_HIDDEN :
-			item_img = gtk_image_new_from_file(SKIN_DIR"user_invisible.png");
+			pixbuf = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"invisible.svg" , 20 , 20 , NULL);
 			break;
 		default :
-			item_img = gtk_image_new_from_file(SKIN_DIR"user_away.png");
+			pixbuf = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"away.svg" , 20 , 20 , NULL);
 			break;
 	}
+	item_img = gtk_image_new_from_pixbuf(pixbuf);
 	gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(item) , item_img);
+	g_object_unref(pixbuf);
 	gtk_menu_shell_append(GTK_MENU_SHELL(menu) , item);
 }
 void fx_head_impre_event_func(GtkWidget* widget , GdkEventButton* event , gpointer data)
 {
 	FxMain* fxmain = (FxMain*)data;
 	FxHead* fxhead = fxmain->headPanel;
+	GdkColor color;
+	gdk_color_parse ("white", &color);
+	GdkCursor* cursor = NULL;
 	const char* text = NULL;
 
 	DEBUG_FOOTPRINT();
@@ -304,10 +380,14 @@ void fx_head_impre_event_func(GtkWidget* widget , GdkEventButton* event , gpoint
 			gtk_widget_hide(widget);
 			break;
 		case GDK_ENTER_NOTIFY :
-			gtk_container_set_border_width(GTK_CONTAINER(fxhead->impre_box) , 2);
+			gtk_widget_modify_bg(fxhead->impre_box, GTK_STATE_NORMAL, &color);
+			cursor = gdk_cursor_new (GDK_HAND2);
+			gdk_window_set_cursor(widget->window , cursor);
 			break;
 		case GDK_LEAVE_NOTIFY :
-			gtk_container_set_border_width(GTK_CONTAINER(fxhead->impre_box) , 0);
+			gtk_widget_modify_bg(fxhead->impre_box, GTK_STATE_NORMAL, NULL);
+			cursor = gdk_cursor_new (GDK_LEFT_PTR);
+			gdk_window_set_cursor(widget->window , cursor);
 			break;
 		default:
 			break;
@@ -406,12 +486,15 @@ void fx_head_change_portrait_func(GtkWidget* widget , GdkEventButton* event , gp
 	if(response == 1)
 	{
 		filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(filechooser));
-		anim_pixbuf = gdk_pixbuf_animation_new_from_file(SKIN_DIR"LoadingImage.gif", NULL); 
-		gtk_image_set_from_animation(GTK_IMAGE(fxmain->headPanel->portrait) , anim_pixbuf);
-		args->fxmain = fxmain;
-		bzero(args->filename , sizeof(args->filename));
-		strcpy(args->filename , filename);
-		g_thread_create(fx_head_change_portrait_thread , args , FALSE , NULL);
+		if (filename)
+		{
+			anim_pixbuf = gdk_pixbuf_animation_new_from_file(SKIN_DIR"LoadingImage.gif", NULL); 
+			gtk_image_set_from_animation(GTK_IMAGE(fxmain->headPanel->portrait) , anim_pixbuf);
+			args->fxmain = fxmain;
+			bzero(args->filename , sizeof(args->filename));
+			strcpy(args->filename , filename);
+			g_thread_create(fx_head_change_portrait_thread , args , FALSE , NULL);
+		}
 	}
 	
 	gtk_widget_destroy(filechooser);
@@ -442,6 +525,7 @@ void* fx_head_change_portrait_thread(void* data)
 		if(pb == NULL)
 			pb = gdk_pixbuf_new_from_file_at_size(filepath , 50 , 50 , NULL);
 		gtk_image_set_from_pixbuf(GTK_IMAGE(fxhead->portrait) , pb);
+		g_object_unref(pb);
 		gdk_threads_leave();
 	}
 	else
@@ -451,7 +535,7 @@ void* fx_head_change_portrait_thread(void* data)
 										GTK_DIALOG_DESTROY_WITH_PARENT,
 										GTK_MESSAGE_WARNING,
 										GTK_BUTTONS_OK,
-										_("Upload avatar failed. Note: This appliaction don't support autocompress "
+										_("Upload avatar failed. Note: This appliaction doesn't support auto-compression "
 										"of image. Please be sure that the avater is in 150px × 150px."));
 		gtk_window_set_title(GTK_WINDOW(dialog), "Warning");
 		gtk_dialog_run(GTK_DIALOG(dialog));
@@ -465,8 +549,30 @@ void* fx_head_change_portrait_thread(void* data)
 		if(pb == NULL)
 			pb = gdk_pixbuf_new_from_file_at_size(filepath , 50 , 50 , NULL);
 		gtk_image_set_from_pixbuf(GTK_IMAGE(fxhead->portrait) , pb);
+		g_object_unref(pb);
 		gdk_threads_leave();
 	}
 	free(args);
 	return NULL;
 }
+
+gboolean fx_head_set_sms_clicked(GtkWidget *widget , gpointer data)
+{
+	FxMain *fxmain = (FxMain*)data;
+	User *user = fxmain->user;
+	FxSmsstat *fxst;
+
+	if(strcmp(user->smsOnLineStatus , "0.00:00:00") == 0 || 
+		strcmp(user->smsOnLineStatus , "0.0:0:0") == 0){
+
+		fxst = fx_smsstat_new(fxmain);
+		fx_smsstat_initialize(fxst);
+		gtk_dialog_run(GTK_DIALOG(fxst->dialog));	
+
+		gtk_widget_destroy(fxst->dialog);
+		free(fxst);
+	}else{
+		fetion_user_set_sms_status(user , 0);
+	}
+	return FALSE;
+}
