@@ -34,10 +34,11 @@ void fx_login_free(FxLogin* fxlogin)
 	DEBUG_FOOTPRINT();
 
 	gtk_widget_destroy(fxlogin->fixed);
-//	free(fxlogin);
+	free(fxlogin);
 }
 
-gboolean fx_login_proxy_button_func(GtkWidget *UNUSED(widget) , GdkEventButton *event , gpointer data)
+gboolean fx_login_proxy_button_func(GtkWidget *UNUSED(widget)
+		, GdkEventButton *event , gpointer data)
 {
 	FxLogin *fxlogin = (FxLogin*)data;
 	Proxy *proxy = fxlogin->proxy;
@@ -51,12 +52,12 @@ gboolean fx_login_proxy_button_func(GtkWidget *UNUSED(widget) , GdkEventButton *
 	switch(event->type)
 	{
 		case GDK_ENTER_NOTIFY :
-			sprintf(text , _("<span color='#7ce1a9'><small> Proxy[%s]</small></span>")
+			sprintf(text , _("<span color='#3465a4'><small> Proxy[%s]</small></span>")
 					, (proxy == NULL || !proxy->proxyEnabled) ? _("Off") : _("On"));
 			gtk_label_set_markup(GTK_LABEL(fxlogin->proxyLabel) , text);
 			break;
 		case GDK_LEAVE_NOTIFY :
-			sprintf(text , _("<span color='#0099ff'><small> Proxy[%s]</small></span>")
+			sprintf(text , _("<span color='#204a87'><small> Proxy[%s]</small></span>")
 					, (proxy == NULL || !proxy->proxyEnabled) ? _("Off") : _("On"));
 			gtk_label_set_markup(GTK_LABEL(fxlogin->proxyLabel) , text);
 			break;
@@ -82,7 +83,6 @@ void fx_login_initialize(FxMain* fxmain)
 	Config* config = NULL;
 	GtkTreeModel* model = NULL;
 	GtkWidget *proxyHbox = NULL;
-	GtkWidget *label = NULL;
 	Proxy *proxy = NULL;
 	char text[1024];
 
@@ -108,6 +108,10 @@ void fx_login_initialize(FxMain* fxmain)
 	fxlogin->password = gtk_entry_new();
 	gtk_widget_set_size_request(GTK_WIDGET(fxlogin->password) , 200 , 25);
 	gtk_entry_set_visibility(GTK_ENTRY(fxlogin->password) , FALSE);
+	g_signal_connect(G_OBJECT(fxlogin->password)
+					 , "activate"
+					 , G_CALLBACK(fx_login_action_func)
+					 , fxmain);
 
 	fxlogin->passlabel = gtk_label_new(_("Please input password:"));
 	gtk_label_set_justify(GTK_LABEL(fxlogin->passlabel) , GTK_JUSTIFY_CENTER);
@@ -131,12 +135,12 @@ void fx_login_initialize(FxMain* fxmain)
 	fxlogin->statecombo = gtk_combo_box_new_with_model(stateModel);
 	g_object_unref(stateModel);
 	renderer = gtk_cell_renderer_pixbuf_new ();
-    gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (fxlogin->statecombo), renderer, FALSE);
-    gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (fxlogin->statecombo), renderer,
+	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (fxlogin->statecombo), renderer, FALSE);
+	gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (fxlogin->statecombo), renderer,
 				    "pixbuf", 0, NULL);
 	renderer = gtk_cell_renderer_text_new();
 	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (fxlogin->statecombo), renderer, FALSE);
-    gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (fxlogin->statecombo), renderer,
+	gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (fxlogin->statecombo), renderer,
 				    "text", 1, NULL);
 	gtk_combo_box_set_active (GTK_COMBO_BOX (fxlogin->statecombo), 3);
 
@@ -149,7 +153,7 @@ void fx_login_initialize(FxMain* fxmain)
 	proxyHbox = gtk_hbox_new(FALSE , FALSE);
 	img = gtk_image_new_from_file(SKIN_DIR"proxy.png");
 	bzero(text , sizeof(text));
-	sprintf(text , _("<span color='#0099ff'><small> Proxy[%s]</small></span>")
+	sprintf(text , _("<span color='#204a87'><small> Proxy[%s]</small></span>")
 			, (fxlogin->proxy == NULL || ! fxlogin->proxy->proxyEnabled) ? _("Off")  : _("On"));
 
 	gtk_label_set_markup(GTK_LABEL(fxlogin->proxyLabel) , text);
@@ -174,24 +178,23 @@ void fx_login_initialize(FxMain* fxmain)
 
 	fx_login_set_last_login_user(fxlogin);
 
-	label = gtk_label_new(NULL);
-	gtk_label_set_markup(GTK_LABEL(label) , "<small>welcome to openfetion</small>");
+	img = gtk_image_new_from_pixbuf(gdk_pixbuf_new_from_file_at_size(SKIN_DIR"fetion.svg" , 128 , 128 , NULL));
 
 	fxlogin->fixed = gtk_fixed_new();
-	gtk_fixed_put(GTK_FIXED(fxlogin->fixed) , label , 50 , 20);
-	gtk_fixed_put(GTK_FIXED(fxlogin->fixed) , fxlogin->userlabel , 20 ,80);
-	gtk_fixed_put(GTK_FIXED(fxlogin->fixed) , fxlogin->username , (WINDOW_WIDTH - 200)/2 , 100 );
-	gtk_fixed_put(GTK_FIXED(fxlogin->fixed) , fxlogin->passlabel , 20 , 130);
-	gtk_fixed_put(GTK_FIXED(fxlogin->fixed) , fxlogin->password , (WINDOW_WIDTH - 200)/2 , 150);
-	gtk_fixed_put(GTK_FIXED(fxlogin->fixed) , fxlogin->statecombo , (WINDOW_WIDTH - 120)/2 , 180);
-	gtk_fixed_put(GTK_FIXED(fxlogin->fixed) , fxlogin->remember , (WINDOW_WIDTH - 80)/2 , 220);
-	gtk_fixed_put(GTK_FIXED(fxlogin->fixed) , fxlogin->label , 5 , 240);
-	gtk_fixed_put(GTK_FIXED(fxlogin->fixed) , fxlogin->loginbutton , (WINDOW_WIDTH - 80)/2 , 270);
-	gtk_fixed_put(GTK_FIXED(fxlogin->fixed) , fxlogin->proxyBtn , (WINDOW_WIDTH - 100) / 2 , 320);
+	gtk_fixed_put(GTK_FIXED(fxlogin->fixed) , img , 70, 25);
+	gtk_fixed_put(GTK_FIXED(fxlogin->fixed) , fxlogin->userlabel , 20 ,165);
+	gtk_fixed_put(GTK_FIXED(fxlogin->fixed) , fxlogin->username , (WINDOW_WIDTH - 200)/2 , 185);
+	gtk_fixed_put(GTK_FIXED(fxlogin->fixed) , fxlogin->passlabel , 20 , 215);
+	gtk_fixed_put(GTK_FIXED(fxlogin->fixed) , fxlogin->password , (WINDOW_WIDTH - 200)/2 , 235);
+	gtk_fixed_put(GTK_FIXED(fxlogin->fixed) , fxlogin->statecombo , (WINDOW_WIDTH - 120)/2 , 265);
+	gtk_fixed_put(GTK_FIXED(fxlogin->fixed) , fxlogin->remember , (WINDOW_WIDTH - 80)/2 , 305);
+	gtk_fixed_put(GTK_FIXED(fxlogin->fixed) , fxlogin->label , 5 , 325);
+	gtk_fixed_put(GTK_FIXED(fxlogin->fixed) , fxlogin->loginbutton , (WINDOW_WIDTH - 80)/2 , 355);
+	gtk_fixed_put(GTK_FIXED(fxlogin->fixed) , fxlogin->proxyBtn , (WINDOW_WIDTH - 100) / 2 , 405);
 	gtk_box_pack_start(GTK_BOX(fxmain->mainbox) , fxlogin->fixed , TRUE , TRUE , 0);
 
-	GTK_WIDGET_SET_FLAGS(fxlogin->loginbutton, GTK_CAN_DEFAULT);
-	gtk_widget_grab_default(fxlogin->loginbutton);
+	GTK_WIDGET_SET_FLAGS(fxlogin->loginbutton, GTK_CAN_FOCUS);
+	gtk_widget_grab_focus(fxlogin->loginbutton);
 
 	gtk_widget_show_all(fxmain->mainbox);
 
@@ -211,15 +214,15 @@ GtkTreeModel* fx_login_create_state_model()
 		const gchar* icon;
 		int type;
 	} presence[] = {
-		{ N_("Online")	 , SKIN_DIR"user_online.png" , P_ONLINE } , 
-		{ N_("Leave")	 , SKIN_DIR"user_away.png" , P_AWAY } , 
-		{ N_("Busy")	 , SKIN_DIR"user_busy.png" , P_BUSY } ,
-		{ N_("Hide")	 , SKIN_DIR"user_invisible.png" , P_HIDDEN } , 
-		{ N_("Eating out") , SKIN_DIR"user_away.png" , P_OUTFORLUNCH } ,
-		{ N_("Do Not Disturb") , SKIN_DIR"user_away.png" , P_DONOTDISTURB } , 
-		{ N_("Back Soon") , SKIN_DIR"user_away.png" , P_RIGHTBACK } , 
-		{ N_("Meeting")	 , SKIN_DIR"user_away.png" , P_MEETING } , 
-		{ N_("Calling")	 , SKIN_DIR"user_away.png" , P_ONTHEPHONE} ,
+		{ N_("Online")	 , SKIN_DIR"online.svg" , P_ONLINE } , 
+		{ N_("Leave")	 , SKIN_DIR"away.svg" , P_AWAY } , 
+		{ N_("Busy")	 , SKIN_DIR"busy.svg" , P_BUSY } ,
+		{ N_("Hide")	 , SKIN_DIR"invisible.svg" , P_HIDDEN } , 
+		{ N_("Eating out") , SKIN_DIR"away.svg" , P_OUTFORLUNCH } ,
+		{ N_("Do Not Disturb") , SKIN_DIR"away.svg" , P_DONOTDISTURB } , 
+		{ N_("Back Soon") , SKIN_DIR"away.svg" , P_RIGHTBACK } , 
+		{ N_("Meeting")	 , SKIN_DIR"away.svg" , P_MEETING } , 
+		{ N_("Calling")	 , SKIN_DIR"away.svg" , P_ONTHEPHONE} ,
 		{ NULL		 , NULL 			   , -1}
 	};
 	enum
@@ -233,7 +236,8 @@ GtkTreeModel* fx_login_create_state_model()
 	for(i = 0 ; presence[i].type != -1 ; i++)
 	{
 		gtk_list_store_append(store , &iter);
-		pb = gdk_pixbuf_new_from_file(presence[i].icon , NULL);
+		pb = gdk_pixbuf_new_from_file_at_size(presence[i].icon,
+				20, 20, NULL);
 		gtk_list_store_set(store , &iter
 				, PIXBUF_COL , pb 
 				, TEXT_COL , _(presence[i].name)
@@ -299,8 +303,7 @@ login:
 	}
 	parse_ssi_auth_response(pos , user);
 	free(pos);
-	if(user->loginStatus == 421 || user->loginStatus == 420)
-	{
+	if(user->loginStatus == 421 || user->loginStatus == 420){
 		debug_info(user->verification->text);
 		debug_info(user->verification->tips);
 		generate_pic_code(user);
@@ -309,16 +312,13 @@ login:
 				, user->verification->tips , CODE_NOT_ERROR);
 		fx_code_initialize(fxcode);
 		ret = gtk_dialog_run(GTK_DIALOG(fxcode->dialog));
-		if(ret == GTK_RESPONSE_OK)
-		{
+		if(ret == GTK_RESPONSE_OK){
 			strcpy(code , gtk_entry_get_text(GTK_ENTRY(fxcode->codeentry)));
 			fetion_user_set_verification_code(user , code);
 			gtk_widget_destroy(fxcode->dialog);
 			free(fxcode);
 			gdk_threads_leave();
-		}
-		else
-		{
+		}else{
 			gtk_widget_destroy(fxcode->dialog);
 			free(fxcode);
 			gdk_threads_leave();
@@ -327,8 +327,7 @@ login:
 		debug_info("Input verfication code:%s" , code);
 		goto login;
 	}
-	if(user->loginStatus == 401 || user->loginStatus == 400)
-	{
+	if(user->loginStatus == 401 || user->loginStatus == 400 || user->loginStatus == 404){
 		debug_info("Password error!!!");
 		fx_login_show_msg(fxlogin , _("Login failed. Incorrect cell phone number or password"));
 		g_thread_exit(0);
@@ -346,20 +345,21 @@ login:
 	ul = fetion_user_list_load(config);
 	newul = fetion_user_list_find_by_no(ul , no);
 	if(newul == NULL){
-		if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(fxlogin->remember))){
+		if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(fxlogin->remember)))
 			newul = fetion_user_list_new(no , password , state , 1);
-		}else{
+		else
 			newul = fetion_user_list_new(no , NULL , state , 1);
-		}
+
 		fetion_user_list_append(ul , newul);
 	}else{
-		bzero(newul->password , sizeof(newul->password));
+		memset(newul->password , 0 , sizeof(newul->password));
 		if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(fxlogin->remember)))
 			strcpy(newul->password , password);
 		newul->laststate = state;
-		foreach_userlist(ul , ul_cur){
+
+		foreach_userlist(ul , ul_cur)
 			ul_cur->islastuser = 0;
-		}
+
 		newul->islastuser = 1;
 	}
 	fetion_user_list_save(config , ul);
@@ -372,7 +372,9 @@ login:
 		fx_login_show_msg(fxlogin , _("Login failed"));
 		return NULL;
 	}
-	fetion_config_load_data(user);
+	if(fetion_config_load_data(user) < 0)
+		fetion_config_save(user);
+
 
 	user->state = state;
 
@@ -453,12 +455,10 @@ auth:
 		}
 		debug_info("Input verfication code:%s" , code);
 	}
+	fx_login_show_msg(fxlogin , _("Initializing main panel"));
 	
-	fx_login_show_msg(fxlogin , _("Login sucessful"));
-
 	pg_group_get_list(user);
 
-	gdk_threads_enter();
 #ifdef USE_LIBNOTIFY
 	char notifyText[1024];
 	char iconPath[256];
@@ -476,18 +476,24 @@ auth:
 		fetion_user_download_portrait(user , user->sipuri);
 		pb = gdk_pixbuf_new_from_file_at_size(iconPath , 48 , 48 , NULL);
 		if(pb == NULL){
-			pb = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"fetion.png" , 48 , 48 , NULL);
+			pb = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"fetion.svg" , 48 , 48 , NULL);
 		}
 	}
+	gdk_threads_enter();
 	notify_notification_update(fxmain->notify , _("Login successful")// notifySummary
 			, notifyText , NULL);
 	notify_notification_set_icon_from_pixbuf(fxmain->notify , pb);
 	notify_notification_show(fxmain->notify , NULL);
+	gdk_threads_leave();
 	g_object_unref(pb);
 #endif
+	fx_login_show_msg(fxlogin , _("Login sucessful"));
+
+	gdk_threads_enter();
 	gtk_window_set_resizable(GTK_WINDOW(fxmain->window) , TRUE);
 	gdk_threads_leave();
 
+
 	/**
 	 *  if there is not a buddylist name "Ungrouped" or "Strangers", create one
 	 */
@@ -506,24 +512,22 @@ auth:
 		fetion_group_list_prepend(user->groupList , group);
 	}
 
-	gdk_threads_enter();
-	fx_login_free(fxlogin);
-	gdk_threads_leave();
-	fxmain->loginPanel = NULL;
 	/* initialize head panel */
 	gdk_threads_enter();
 	fx_head_initialize(fxmain);
-	DEBUG_FOOTPRINT();
 	gdk_threads_leave();
+
 	/* initialize main panel which in fact only contains a treeview*/
 	gdk_threads_enter();
 	fxmain->mainPanel = fx_tree_new();
 	fx_tree_initilize(fxmain);
 	gdk_threads_leave();
+
 	/* initialize bottom panel */
 	gdk_threads_enter();
 	fx_bottom_initialize(fxmain);
 	gdk_threads_leave();
+
 	/* set tooltip of status icon */
 	bzero(statusTooltip , sizeof(statusTooltip));
 	sprintf(statusTooltip , "%s\n%s" , user->nickname , user->mobileno);
@@ -533,8 +537,22 @@ auth:
 	/* set title of main window*/
 	gtk_window_set_title(GTK_WINDOW(fxmain->window) , user->nickname );
 	gdk_threads_leave();
+
+	gdk_threads_enter();
+	fx_login_free(fxlogin);
+	fxmain->loginPanel = NULL;
+	gdk_threads_leave();
+
+	gdk_threads_enter();
+	fx_head_show(fxmain);
+	fx_tree_show(fxmain);
+	fx_bottom_show(fxmain);
+	gdk_threads_leave();
+
+
 	/* start sending keep alive request periodically */
 	g_timeout_add_seconds(180 , (GSourceFunc)fx_main_register_func , user);
+	g_timeout_add_seconds(10 , (GSourceFunc)fx_main_check_func , fxmain);
 
 	/*====================================*/
 
