@@ -20,6 +20,8 @@
 
 #include "fx_include.h"
 
+static void fx_lookup_on_entry_activated(GtkWidget *UNUSED(widget) , gpointer data);
+
 FxLookup* fx_lookup_new(FxMain* fxmain)
 {
 	FxLookup *fxlookup = (FxLookup*)malloc(sizeof(FxLookup));
@@ -48,12 +50,14 @@ void fx_lookup_initialize(FxLookup* fxlookup)
 	gtk_widget_set_usize(fxlookup->dialog , 300 , 150);
 	gtk_container_set_border_width(GTK_CONTAINER(fxlookup->dialog) , 20);
 
-	fxlookup->remark_label = gtk_label_new(_("Please input users phone number or fetion number:"));
+	fxlookup->remark_label = gtk_label_new(_("Please input the user's phone number or fetion number:"));
 	gtk_misc_set_alignment(GTK_MISC(fxlookup->remark_label) , 0 , 0 );
 	gtk_box_pack_start_defaults(GTK_BOX(GTK_DIALOG(fxlookup->dialog)->vbox) , fxlookup->remark_label);
 
 	fxlookup->remark_entry = gtk_entry_new();
 	gtk_box_pack_start_defaults(GTK_BOX(GTK_DIALOG(fxlookup->dialog)->vbox) , fxlookup->remark_entry);
+	g_signal_connect(fxlookup->remark_entry , "activate" 
+			, G_CALLBACK(fx_lookup_on_entry_activated) , fxlookup);
 
 	fxlookup->ok_button = gtk_button_new_with_label(_("Find"));
 	gtk_box_pack_start_defaults(GTK_BOX(GTK_DIALOG(fxlookup->dialog)->action_area) , fxlookup->ok_button);
@@ -121,3 +125,10 @@ void fx_lookup_on_cancel_clicked(GtkWidget* UNUSED(widget) , gpointer data)
 
 	gtk_dialog_response(GTK_DIALOG(data) , GTK_RESPONSE_CANCEL);
 }
+
+static void fx_lookup_on_entry_activated(GtkWidget *UNUSED(widget) , gpointer data)
+{
+	DEBUG_FOOTPRINT();
+
+	g_thread_create(fx_lookup_ok_thread , data , FALSE , NULL);
+}
