@@ -25,18 +25,22 @@
 #include <glib/gi18n.h>
 #include <sys/select.h>
 #include <locale.h>
+#include <glib.h>
 int window_pos_x;
 int window_pos_y;
 int window_pos_x_old = 0;
 int window_pos_y_old = 0;
+extern struct unacked_list *unackedlist;
+GStaticMutex mutex = G_STATIC_MUTEX_INIT;
 
 static void fx_main_process_pggetgroupinfo(FxMain *fxmain , const char *sipmsg);
 static void fx_main_process_pgpresencechanged(FxMain *fxmain , const char *sipmsg);
+static gboolean key_press_func(GtkWidget *widget , GdkEventKey *event
+		, gpointer data);
 
 FxMain* fx_main_new()
 {
 	FxMain* fxmain = (FxMain*)malloc(sizeof(FxMain));
-
 	DEBUG_FOOTPRINT();
 
 	memset(fxmain , 0 , sizeof(FxMain));
@@ -79,6 +83,10 @@ void fx_main_initialize(FxMain* fxmain)
 				  , "delete-event"
 				  , G_CALLBACK(fx_main_delete)
 				  , fxmain);
+	g_signal_connect(G_OBJECT(fxmain->window)
+				  , "key-press-event"
+				  , G_CALLBACK(key_press_func)
+				  , fxmain);
 	g_signal_connect(G_OBJECT(fxmain->window)
 				  , "destroy"
 				  , G_CALLBACK(fx_main_destroy)
@@ -95,9 +103,9 @@ void fx_main_initialize(FxMain* fxmain)
 #endif
 
 	gtk_window_set_default_size(GTK_WINDOW(fxmain->window) , WINDOW_WIDTH , WINDOW_HEIGHT);
-	GdkPixbuf* icon = gdk_pixbuf_new_from_file(SKIN_DIR"user_online.png" , NULL);
+	GdkPixbuf* icon = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"fetion.svg" , 48 , 48 , NULL);
 	gtk_window_set_icon(GTK_WINDOW(fxmain->window) , icon);
-	fxmain->trayIcon = gtk_status_icon_new_from_file(SKIN_DIR"invisible_big.png");
+	fxmain->trayIcon = gtk_status_icon_new_from_file(SKIN_DIR"offline.svg");
 	gtk_status_icon_set_tooltip(fxmain->trayIcon , "OpenFetion");
 #ifdef USE_LIBNOTIFY
 	fxmain->notify = notify_notification_new_with_status_icon("welcome"
@@ -182,8 +190,10 @@ GtkWidget* fx_main_create_menu1(const char* name
 							 )
 {
 	GtkWidget *item = gtk_image_menu_item_new_with_label(name);
+#if 0
 	GtkWidget *img = gtk_image_new_from_stock(stockid , GTK_ICON_SIZE_MENU);
 	gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(item) , img);
+#endif
 	gtk_menu_shell_append(GTK_MENU_SHELL(parent) , item);
 	if(func != NULL)
 		g_signal_connect(item , "activate" , G_CALLBACK(func) , data);
@@ -266,7 +276,8 @@ void fx_main_process_presence(FxMain* fxmain , const char* xml)
 	contact = contactlist;
 	model = gtk_tree_view_get_model(GTK_TREE_VIEW(treeView));
 	foreach_contactlist(contactlist , contact){
-		fx_tree_get_buddy_iter_by_userid(model , contact->userId , &iter);
+		if(fx_tree_get_buddy_iter_by_userid(model , contact->userId , &iter) == -1)
+				continue;
 		gtk_tree_model_get(model , &iter
 						 , B_CRC_COL    , &crc
 						 , B_STATE_COL  , &oldstate
@@ -318,7 +329,7 @@ void fx_main_process_presence(FxMain* fxmain , const char* xml)
 						, contact->impression );
 				pb = gdk_pixbuf_new_from_file_at_size(iconPath , 48 , 48 , NULL);
 				if(pb == NULL){
-					pb = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"fetion.png" , 48 , 48 , NULL);
+					pb = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"fetion.svg" , 48 , 48 , NULL);
 				}
 				notify_notification_update(fxmain->notify , notifySummary
 						, notifyText , NULL);
@@ -328,8 +339,7 @@ void fx_main_process_presence(FxMain* fxmain , const char* xml)
 			}
 #endif
 		}
-		if(fxchat != NULL)
-		{
+		if(fxchat != NULL){
 			fxchat->state = contact->state;
 		}
 		name = (contact->nickname == NULL || strlen(contact->localname) == 0) ? contact->nickname : contact->localname;
@@ -425,7 +435,7 @@ static void process_group_message(FxMain *fxmain , Message *message)
 		free(sid);
 		pixbuf = gdk_pixbuf_new_from_file(path , NULL);
 		if(pixbuf == NULL)
-			pixbuf = gdk_pixbuf_new_from_file(SKIN_DIR"online_big.png" , NULL);
+			pixbuf = gdk_pixbuf_new_from_file(SKIN_DIR"online.svg" , NULL);
 		gtk_status_icon_set_from_pixbuf(GTK_STATUS_ICON(fxmain->trayIcon) , pixbuf);
 		g_object_unref(pixbuf);
 		gtk_status_icon_set_blinking(GTK_STATUS_ICON(fxmain->trayIcon) , TRUE);
@@ -475,20 +485,25 @@ void fx_main_process_message(FxMain* fxmain , FetionSip* sip , const char* sipms
 		{
 			sid = fetion_sip_get_sid_by_sipuri(msg->sipuri);
 			/* system message */
-			if(strlen(sid) < 8 || strcmp(sid , "10000") == 0){
+			if(strlen(sid) < 5 || strcmp(sid , "10000") == 0){
 				free(sid);
 				sid = NULL;
 				process_system_message(sipmsg);
+				fetion_message_free(msg);
 				gdk_threads_leave();
 				return;
 			}
 			if(config->autoPopup == AUTO_POPUP_ENABLE){
 				fxchat = fx_main_create_chat_window(fxmain , msg->sipuri);
 				if(fxchat == NULL){
+					fetion_message_free(msg);
 					gdk_threads_leave();
 					return;
 				}
-				fx_chat_add_message(fxchat , msg->message , &(msg->sendtime) , 0);
+				fx_chat_add_message(fxchat , msg->message,
+								&(msg->sendtime) , 0 , msg->sysback);
+				fetion_message_free(msg);
+				return;
 			}else{
 				mitem = fx_list_new(msg);
 				fx_list_append(fxmain->mlist , mitem );
@@ -502,8 +517,8 @@ void fx_main_process_message(FxMain* fxmain , FetionSip* sip , const char* sipms
 				if(config->msgAlert == MSG_ALERT_ENABLE){	
 					senderContact = fetion_contact_list_find_by_sipuri(user->contactList , msg->sipuri);
 					if( senderContact){
-						bzero(notifySum , sizeof(notifySum));
-						bzero(iconPath , sizeof(iconPath));
+						memset(notifySum , 0 , sizeof(notifySum));
+						memset(iconPath , 0 , sizeof(iconPath));
 						sprintf(iconPath , "%s/%s.jpg" , config->iconPath , senderContact->sId);
 						senderSid = fetion_sip_get_sid_by_sipuri(msg->sipuri);
 						sprintf(notifySum , _("%s(%s) said:") , senderContact->nickname , senderContact->sId);
@@ -521,16 +536,17 @@ void fx_main_process_message(FxMain* fxmain , FetionSip* sip , const char* sipms
 #endif
 			}
 		}else{
-			fx_chat_add_message(fxchat , msg->message , &(msg->sendtime) , 0);
+			fx_chat_add_message(fxchat , msg->message,
+						 &(msg->sendtime) , 0 , msg->sysback);
 		}
-		bzero(path , sizeof(path));
+		memset(path , 0 , sizeof(path));
 		sid = fetion_sip_get_sid_by_sipuri(msg->sipuri);
 		sprintf(path , "%s/%s.jpg" , config->iconPath , sid);
 		free(sid);
 		sid = NULL;
 		pb = gdk_pixbuf_new_from_file(path , NULL);
 		if(pb == NULL)
-			pb = gdk_pixbuf_new_from_file(SKIN_DIR"online_big.png" , NULL);
+			pb = gdk_pixbuf_new_from_file(SKIN_DIR"online.svg" , NULL);
 		gtk_status_icon_set_from_pixbuf(GTK_STATUS_ICON(fxmain->trayIcon) , pb);
 		g_object_unref(pb);
 		gtk_status_icon_set_blinking(GTK_STATUS_ICON(fxmain->trayIcon) , TRUE);
@@ -540,10 +556,16 @@ void fx_main_process_message(FxMain* fxmain , FetionSip* sip , const char* sipms
 							, "activate"
 							, GTK_SIGNAL_FUNC(fx_main_message_func)
 							, fxmain);
+		/* no message was pushed into the message queue,just free it */
+		if(fxchat && fxchat->hasFocus == CHAT_DIALOG_NOT_FOCUSED)
+			fetion_message_free(msg);
 	}
 	else
 	{
-		fx_chat_add_message(fxchat , msg->message , &(msg->sendtime) , 0);
+		fx_chat_add_message(fxchat , msg->message,
+					   	&(msg->sendtime) , 0, msg->sysback);
+		/* message was showed in the chat dialog directly,just free it */
+		fetion_message_free(msg);
 	}
 	gdk_threads_leave();
 	if(config->isMute == MUTE_DISABLE)
@@ -578,8 +600,7 @@ void fx_main_process_user_left(FxMain* fxmain , const char* msg)
 	 * else just exit current thread
 	 */
 	fxchat = fx_list_find_chat_by_sipuri(clist , sipuri);
-	if(fxchat == NULL)
-	{
+	if(fxchat == NULL) {
 		debug_info("User %s left conversation" , sipuri);
 		debug_info("Thread exit");
 		free(sipuri);
@@ -609,8 +630,7 @@ FxChat* fx_main_create_chat_window(FxMain* fxmain , const char* sipuri)
 	conv = fetion_conversation_new(fxmain->user , sipuri , NULL);
 	
 	/* this buddy is not in the friend list*/
-	if(conv == NULL)
-	{
+	if(conv == NULL) {
 		sid = fetion_sip_get_sid_by_sipuri(sipuri);
 		if(strlen(sid) < 8 || strcmp(sid , "10000") == 0)
 			return NULL;
@@ -669,7 +689,6 @@ void fx_main_process_invitation(FxMain* fxmain , const char* sipmsg)
 	timeout = timeout_args_new(fxmain , osip , sipuri);
 	list = fx_list_new(timeout);
 	fx_list_append(fxmain->tlist , list);
-	g_timeout_add_seconds(120 , (GSourceFunc)fx_main_chat_keep_alive_func , timeout);
 } 
 #if 0
 static void process_share_action_accept(FxMain *fxmain
@@ -696,8 +715,7 @@ void fx_main_process_incoming(FxMain* fxmain
 	DEBUG_FOOTPRINT();
 
 	fetion_sip_parse_incoming(sip , sipmsg , &sipuri , &type , &action);
-	switch(type)
-	{
+	switch(type) {
 		case INCOMING_NUDGE :
 			{
 				gdk_threads_enter();
@@ -753,6 +771,8 @@ void fx_main_process_sipc(FxMain* fxmain , const char* sipmsg)
 	char *xml = NULL;
 	User *user = fxmain->user;
 
+	struct unacked_list *ulist;
+	
 	PGGroup *pggroup = user->pggroup;
 	PGGroup *pgcur;
 
@@ -760,10 +780,21 @@ void fx_main_process_sipc(FxMain* fxmain , const char* sipmsg)
 
 	/* get group info response */
 	if(callid == user->pgGroupCallId){
+		gdk_threads_enter();
 		fx_main_process_group(fxmain , xml);
+		gdk_threads_leave();
 		return;
 	}
 
+	foreach_unacked_list(unackedlist , ulist) {
+		if(callid == ulist->message->callid){
+			unacked_list_remove(unackedlist , ulist);
+			fetion_message_free(ulist->message);
+			free(ulist);
+			return;
+		}
+	}
+
 	if(pggroup != NULL){
 		foreach_pg_group(pggroup , pgcur){
 #if 0
@@ -818,20 +849,18 @@ void fx_main_process_syncuserinfo(FxMain* fxmain , const char* xml)
 	if(contact == NULL)
 		return;
 	gtk_tree_model_get_iter_root(model , &iter);
-	do
-	{
-		if(gtk_tree_model_iter_children(model , &cIter , &iter))
-		{
-			do
-			{
+	do {
+		if(gtk_tree_model_iter_children(model , &cIter , &iter)){
+			do{
 				gtk_tree_model_get(model , &cIter , B_USERID_COL , &userid , -1);
-				if(strcmp(userid , contact->userId) == 0)
-				{
+				if(strcmp(userid , contact->userId) == 0){
 
+					gdk_threads_enter();
 					gtk_tree_store_set(GTK_TREE_STORE(model) , &cIter
 									 , B_SIPURI_COL			 , contact->sipuri
 									 , B_RELATIONSTATUS_COL	 , contact->relationStatus
 									 , -1);
+					gdk_threads_leave();
 					free(userid);
 					goto end;
 				}
@@ -1030,9 +1059,10 @@ static void fx_main_direct_sms_clicked(GtkWidget *UNUSED(widget) , gpointer data
 void fx_main_tray_popmenu_func(GtkWidget* UNUSED(widget)
 		, guint button , guint activate_time , gpointer data)
 {
-	FxMain* fxmain = (FxMain*)data;
+	FxMain *fxmain = (FxMain*)data;
+	User *user = fxmain->user;
 	Config *config = NULL;
-	GtkWidget *muteItem;
+	GtkWidget *item;
 	char stateMenu[48];
 	int i;
 	typedef struct 
@@ -1050,15 +1080,15 @@ void fx_main_tray_popmenu_func(GtkWidget* UNUSED(widget)
 		const gchar* icon;
 		int type;
 	} presence[] = {
-		{ N_("Online")	 , SKIN_DIR"user_online.png" , P_ONLINE } , 
-		{ N_("Leave")	 , SKIN_DIR"user_away.png" , P_AWAY } , 
-		{ N_("Busy")	 , SKIN_DIR"user_busy.png" , P_BUSY } ,
-		{ N_("Hide")	 , SKIN_DIR"user_invisible.png" , P_HIDDEN } , 
-		{ N_("Eating out") , SKIN_DIR"user_away.png" , P_OUTFORLUNCH } ,
-		{ N_("Do Not Disturb") , SKIN_DIR"user_away.png" , P_DONOTDISTURB } , 
-		{ N_("Back Soon") , SKIN_DIR"user_away.png" , P_RIGHTBACK } , 
-		{ N_("Meeting")	 , SKIN_DIR"user_away.png" , P_MEETING } , 
-		{ N_("Calling")	 , SKIN_DIR"user_away.png" , P_ONTHEPHONE} ,
+		{ N_("Online")	 , SKIN_DIR"online.svg" , P_ONLINE } , 
+		{ N_("Leave")	 , SKIN_DIR"away.svg" , P_AWAY } , 
+		{ N_("Busy")	 , SKIN_DIR"busy.svg" , P_BUSY } ,
+		{ N_("Hide")	 , SKIN_DIR"invisible.svg" , P_HIDDEN } , 
+		{ N_("Eating out") , SKIN_DIR"away.svg" , P_OUTFORLUNCH } ,
+		{ N_("Do Not Disturb") , SKIN_DIR"away.svg" , P_DONOTDISTURB } , 
+		{ N_("Back Soon") , SKIN_DIR"away.svg" , P_RIGHTBACK } , 
+		{ N_("Meeting")	 , SKIN_DIR"away.svg" , P_MEETING } , 
+		{ N_("Calling")	 , SKIN_DIR"away.svg" , P_ONTHEPHONE} ,
 		{ NULL		 , NULL 			   , -1}
 	};
 
@@ -1074,13 +1104,25 @@ void fx_main_tray_popmenu_func(GtkWidget* UNUSED(widget)
 	if(fxmain->user != NULL && fxmain->user->loginStatus != -1)
 	{
 		config = fxmain->user->config;
-		muteItem = gtk_check_menu_item_new_with_label(_("Close sound"));
+
+		item = gtk_check_menu_item_new_with_label(_("Close sound"));
 		if(config->isMute == MUTE_ENABLE)
-			gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(muteItem) , TRUE);
+			gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item) , TRUE);
 		else
-			gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(muteItem) , FALSE);
-		g_signal_connect(muteItem , "activate" , G_CALLBACK(fx_main_mute_clicked) , fxmain);
-		gtk_menu_shell_append(GTK_MENU_SHELL(menu) , muteItem);
+			gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item) , FALSE);
+		g_signal_connect(item , "activate" , G_CALLBACK(fx_main_mute_clicked) , fxmain);
+		gtk_menu_shell_append(GTK_MENU_SHELL(menu) , item);
+
+
+		item = gtk_check_menu_item_new_with_label(_("Receive SMS"));
+		if(strcmp(user->smsOnLineStatus , "0.00:00:00") &&
+			strcmp(user->smsOnLineStatus , "0.0:0:0"))
+			gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item) , FALSE);
+		else
+			gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item) , TRUE);
+		gtk_menu_shell_append(GTK_MENU_SHELL(menu) , item);
+		g_signal_connect(item , "activate" , G_CALLBACK(fx_head_set_sms_clicked) , fxmain);
+
 		fx_main_create_menu1(_("Information query") , GTK_STOCK_FIND
 						 , menu , fx_main_info_lookup_clicked , fxmain);
 		if(fxmain->user->boundToMobile == BOUND_MOBILE_ENABLE){
@@ -1094,7 +1136,7 @@ void fx_main_tray_popmenu_func(GtkWidget* UNUSED(widget)
 			args = (Args*)malloc(sizeof(Args));
 			args->fxmain = fxmain;
 			args->type = presence[i].type;
-			bzero(stateMenu , sizeof(stateMenu));
+			memset(stateMenu , 0 , sizeof(stateMenu));
 			sprintf(stateMenu , "%s      " , _(presence[i].name));
 			fx_main_create_menu(stateMenu , presence[i].icon
 							 , submenu , fx_main_set_state_clicked , args);
@@ -1112,7 +1154,7 @@ void fx_main_tray_popmenu_func(GtkWidget* UNUSED(widget)
 						 , menu , fx_main_system_setting_clicked , fxmain);
 	}
 
-	fx_main_create_menu1(_("Exit Openfetion ") , GTK_STOCK_QUIT
+	fx_main_create_menu1(_("Exit OpenFetion ") , GTK_STOCK_QUIT
 					 , menu , fx_main_destroy , fxmain);
 	gtk_widget_show_all(menu);
 	gtk_menu_popup(GTK_MENU(menu) , NULL , NULL , NULL , NULL 
@@ -1125,7 +1167,6 @@ int main(int argc , char* argv[])
 
 	setlocale(LC_ALL, "");
 	bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
-	printf("%s\n" , LOCALE_DIR);
 	bindtextdomain(GETTEXT_PACKAGE , LOCALE_DIR);
 	textdomain(GETTEXT_PACKAGE);
 
@@ -1142,12 +1183,12 @@ int main(int argc , char* argv[])
 #endif
 	gtk_init(&argc , &argv);
 
-	gtk_rc_parse(RESOURCE_DIR"style.rc");
 
 	DEBUG_FOOTPRINT();
 
 	fx_main_initialize(fxmain);
 
+
 	return 0;
 }
 void* fx_main_listen_thread_func(void* data)
@@ -1168,10 +1209,14 @@ void* fx_main_listen_thread_func(void* data)
 	for(;;){
 		
 		if(fxmain == NULL)
-			g_thread_exit(0);
+			return NULL;
+
 		FD_ZERO(&fd_read);
+
+		g_static_mutex_lock(&mutex);
 		FD_SET(sip->tcp->socketfd, &fd_read);
-		ret = select (sip->tcp->socketfd+1, &fd_read, NULL, NULL, NULL);
+		g_static_mutex_unlock(&mutex);
+		ret = select(sip->tcp->socketfd+1, &fd_read, NULL, NULL, NULL);
 		if (ret == -1 || ret == 0) {
 			debug_info ("Error.. to read socket");
 			g_thread_exit(0);
@@ -1183,6 +1228,15 @@ void* fx_main_listen_thread_func(void* data)
 		}
 
 		msg = fetion_sip_listen(sip);
+		if(!msg){
+			gdk_threads_enter();
+			fx_util_popup_warning(fxmain , _("Sorry,your network connection has been closed\n"
+				"Please check your network connection and then login again"));
+			gdk_threads_leave();
+
+			gtk_main_quit();
+			return NULL;
+		}
 		pos = msg;
 		while(pos != NULL){
 			type = fetion_sip_get_type(pos->message);
@@ -1211,7 +1265,8 @@ void* fx_main_listen_thread_func(void* data)
 		if(msg != NULL)
 			fetion_sip_message_free(msg);
 	}
-	g_thread_exit(0);
+
+	return NULL;
 }
 void fx_main_message_func(GtkWidget *UNUSED(widget) , gpointer data)
 {
@@ -1240,15 +1295,16 @@ void fx_main_message_func(GtkWidget *UNUSED(widget) , gpointer data)
 			    printf("%s:%s\n" , msg->sipuri ,  msg->message);
 			    continue;
 		    }
-		    fx_chat_add_message(fxchat , msg->message , &(msg->sendtime) , 0);
+		    fx_chat_add_message(fxchat , msg->message,
+					&(msg->sendtime) , 0 , msg->sysback);
 		}else{
 			/*group message*/
 		    fxpg = pg_create_window(fxmain , msg->pguri);
 		    foreach_pg_member(fxpg->pggroup->member , memcur){
-			if(strcmp(memcur->sipuri , msg->sipuri) == 0){
+				if(strcmp(memcur->sipuri , msg->sipuri) == 0){
 			    	pg_add_message(fxpg , msg->message , &(msg->sendtime) , memcur );
-				break;
-			}
+					break;
+				}
 		    }
 		}
 		fetion_message_free(msg);
@@ -1267,28 +1323,36 @@ void fx_main_message_func(GtkWidget *UNUSED(widget) , gpointer data)
 }
 gboolean fx_main_register_func(User* user)
 {
-	if(fetion_user_keep_alive(user) < 0){
-		debug_info("网络连接已断开,请重新登录");
-		gtk_main_quit();
-		return FALSE;
-	}
+	if(fetion_user_keep_alive(user) < 0)
+		debug_info("network connection terminated,retrying...");
 	return TRUE;
 }
 
-gboolean fx_main_chat_keep_alive_func(TimeOutArgs* args)
+gboolean fx_main_check_func(FxMain* fxmain)
 {
-	if(fetion_sip_keep_alive(args->sip) < 0)
-		return FALSE;
-	if(args->terminated == TRUE)
-	{
-		fx_list_remove_timeout_by_sipuri(args->fxmain->tlist , args->sipuri);
+	struct unacked_list *list;
+	struct tm *now;
+	char *msg;
+	time_t now_t , msg_time_t;
+	long seconds;
 
-		fetion_sip_free(args->sip);
-		free(args);
-		return FALSE;
+	now = get_currenttime();
+	foreach_unacked_list(unackedlist , list){
+		now_t = mktime(now);
+		msg_time_t = mktime(&(list->message->sendtime));
+		seconds = (long)now_t - (long)msg_time_t;
+		if(seconds > 10) {
+			unacked_list_remove(unackedlist , list);
+			msg = contruct_message_sip(fxmain->user->sId , list->message);
+			fx_main_process_message(fxmain , fxmain->user->sip , msg);
+			free(msg);
+			fetion_message_free(list->message);
+			free(list);
+		}
 	}
 	return TRUE;
 }
+
 void fx_main_about_fetion_clicked(GtkWidget *UNUSED(widget) , gpointer UNUSED(data))
 {
 	GtkWidget *dialog = gtk_about_dialog_new();
@@ -1304,7 +1368,7 @@ void fx_main_about_fetion_clicked(GtkWidget *UNUSED(widget) , gpointer UNUSED(da
 	logo = gdk_pixbuf_new_from_file(SKIN_DIR"about.png" , NULL);
 	gtk_window_set_icon(GTK_WINDOW(dialog) , logo);
 	gtk_about_dialog_set_comments(GTK_ABOUT_DIALOG(dialog), 
-	_("OpenFetion is a non-profit software, to make linux user convenient to use "
+	_("OpenFetion is a non-profit software, aiming at making linux users convenient to use "
 	"fetion."));
 	gtk_about_dialog_set_website(GTK_ABOUT_DIALOG(dialog), 
 	"http://www.basiccoder.com/openfetion");
@@ -1315,7 +1379,7 @@ void fx_main_about_fetion_clicked(GtkWidget *UNUSED(widget) , gpointer UNUSED(da
 void fx_main_check_update_clicked(GtkWidget* UNUSED(widget) , gpointer UNUSED(data))
 {
 	if(fork() == 0){
-		execlp("firefox" , "firefox" , "http://basiccoder.com/openfetion" , (char**)NULL);
+		execlp("xdg-open" , "xdg-open" , "http://basiccoder.com/openfetion" , (char**)NULL);
 		return;
 	}
 }
@@ -1323,7 +1387,7 @@ void fx_main_check_update_clicked(GtkWidget* UNUSED(widget) , gpointer UNUSED(da
 void fx_main_about_author_clicked(GtkWidget* UNUSED(widget) , gpointer UNUSED(data))
 {
 	if(fork() == 0){
-		execlp("firefox" , "firefox" , "http://www.basiccoder.com" , (char**)NULL);
+		execlp("xdg-open" , "xdg-open" , "http://basiccoder.com" , (char**)NULL);
 		return;
 	}
 }
@@ -1542,7 +1606,9 @@ static void fx_main_process_pggetgroupinfo(FxMain *fxmain , const char *sipmsg)
 {
 	PGGroup *pggroup = fxmain->user->pggroup;
 	pg_group_parse_info(pggroup , sipmsg);
+	gdk_threads_enter();
 	fx_tree_bind_pg_data(fxmain);
+	gdk_threads_leave();
 
 }
 static void fx_main_process_pgpresencechanged(FxMain *fxmain , const char *sipmsg)
@@ -1560,3 +1626,26 @@ static void fx_main_process_pgpresencechanged(FxMain *fxmain , const char *sipms
 	}
 #endif
 }
+
+static gboolean key_press_func(GtkWidget *widget , GdkEventKey *event
+		, gpointer data)
+{
+	if(event->keyval == GDK_w){
+		if(event->state & GDK_CONTROL_MASK){
+			gtk_window_iconify(GTK_WINDOW(widget));
+			return TRUE;
+		}else{
+			return FALSE;
+		}
+	}
+	if(event->keyval == GDK_q){
+		if(event->state & GDK_CONTROL_MASK){
+			fx_main_delete(widget , NULL , data);
+			return TRUE;
+		}else{
+			return FALSE;
+		}
+	}
+
+	return FALSE;
+}
