@@ -21,14 +21,12 @@
 #include "fx_include.h"
 
 static void fx_many_add_information(FxMany* fxmany , const char* text);
-
 static void fx_many_on_close_clicked(GtkWidget* UNUSED(widget) , gpointer data);
-
 static void fx_many_on_send_clicked(GtkWidget* UNUSED(widget) , gpointer data);
-
 static void* fx_many_sms_send_func(void* data);
-
 static GtkTreeModel* fx_many_create_all_model(FxMany* fxmany);
+static gboolean key_press_func(GtkWidget *UNUSED(widget) , GdkEventKey *event
+		, gpointer data);
 
 FxMany* fx_many_new(FxMain* fxmain)
 {
@@ -87,6 +85,7 @@ static GtkTreeModel* fx_many_create_all_model(FxMany* fxmany)
 								 , S_NAME_COL   , name
 								 , S_SIPURI_COL , sipuri
 								 , -1);
+				g_object_unref(pb);
 				free(name);
 				free(sipuri);
 			}
@@ -398,8 +397,11 @@ void fx_many_initialize(FxMany* fxmany)
 	fxmany->dialog = gtk_dialog_new();
 	pb = gdk_pixbuf_new_from_file(SKIN_DIR"groupsend.png" , NULL);
 	gtk_window_set_icon(GTK_WINDOW(fxmany->dialog) , pb);
+	g_object_unref(pb);
 	gtk_window_set_title(GTK_WINDOW(fxmany->dialog) , _("SMS To Many"));
 	gtk_widget_set_usize(fxmany->dialog , 660 , 520);
+	g_signal_connect(fxmany->dialog , "key-press-event"
+			, G_CALLBACK(key_press_func) , fxmany);
 	gtk_container_set_border_width(GTK_CONTAINER(fxmany->dialog) , 5);
 
 	fxmany->hbox = gtk_hbox_new(FALSE , 0);
@@ -568,8 +570,8 @@ static void* fx_many_sms_send_func(void* data)
 			if(fetion_conversation_send_sms_to_phone_with_reply(conv
 						, text , &daycount , &monthcount) > 0){
 				bzero(alertmsg , sizeof(alertmsg));
-				sprintf(alertmsg , _("Mesage \"%s\" has been sent to \"%s\". Today you have sent %d and this "
-						 "month %d\n") , text , name , daycount , monthcount);
+				sprintf(alertmsg , _("Mesage \"%s\" has been sent to \"%s\". You have sent %d today and "
+						 "%d this month\n") , text , name , daycount , monthcount);
 			}else{
 				sprintf(alertmsg , _("Mesage \"%s\" did not send to \"%s\"\n") , text , name);
 			}
@@ -582,3 +584,20 @@ static void* fx_many_sms_send_func(void* data)
 	}
 	return NULL;
 }
+
+static gboolean key_press_func(GtkWidget *UNUSED(widget) , GdkEventKey *event
+		, gpointer data)
+{
+	FxMany *fxmany ;
+	if(event->keyval == GDK_w){
+		if(event->state & GDK_CONTROL_MASK){
+			fxmany = (FxMany*)data;
+			gtk_dialog_response(GTK_DIALOG(fxmany->dialog) , GTK_RESPONSE_OK);
+			return TRUE;
+		}else{
+			return FALSE;
+		}
+	}
+
+	return FALSE;
+}
