@@ -20,6 +20,8 @@
 
 #include <fx_include.h>
 
+static GStaticMutex pg_mutex = G_STATIC_MUTEX_INIT;
+
 static void on_close_clicked(GtkWidget *UNUSED(widget) , gpointer data);
 static void on_send_clicked(GtkWidget *UNUSED(widget) , gpointer data);
 static GtkTreeModel *create_model(PGGroup *pggroup);
@@ -49,6 +51,8 @@ static void on_double_click(GtkTreeView *treeview
 		, gpointer data);
 static void *on_contact_show(void *data);
 static void pg_window_destroy(GtkWidget *UNUSED(widget) , gpointer data);
+static gboolean key_press_func(GtkWidget *UNUSED(widget) , GdkEventKey *event
+		, gpointer data);
 
 FxPGGroup *fx_pggroup_new(FxMain *fxmain , PGGroup *pggroup)
 {
@@ -95,6 +99,8 @@ void fx_pggroup_initialize(FxPGGroup *fxpggroup )
 	gtk_window_set_title(GTK_WINDOW(fxpggroup->window) , text);
 	g_signal_connect(fxpggroup->window , "destroy"
 	       	, G_CALLBACK(pg_window_destroy) , fxpggroup);
+	g_signal_connect(fxpggroup->window , "key-press-event"
+			, G_CALLBACK(key_press_func) , fxpggroup);
 	pixbuf = gdk_pixbuf_new_from_file(SKIN_DIR"pggroup.png" , NULL);
 	gtk_window_set_icon(GTK_WINDOW(fxpggroup->window) , pixbuf);
 	gtk_widget_set_size_request(fxpggroup->window , 650 , 490);
@@ -302,22 +308,22 @@ static GtkTreeModel *create_model(PGGroup *pggroup)
 	foreach_pg_member(member , mcur){
 		if(mcur->state <= 0){
 		    gtk_tree_store_append(store , &iter , NULL);
-		    pixbuf = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"invisible_big.png"
+		    pixbuf = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"invisible.svg"
 			    , MEMBER_PROTRAIT_SIZED , MEMBER_PROTRAIT_SIZED , NULL);
 		}
 		else{
 		    gtk_tree_store_prepend(store , &iter , NULL);
 		    switch(mcur->state){
 			case P_ONLINE :
-				pixbuf = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"online_big.png"
+				pixbuf = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"online.svg"
 				       	, MEMBER_PROTRAIT_SIZED , MEMBER_PROTRAIT_SIZED , NULL);
 				break;
 			case P_BUSY :
-				pixbuf = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"busy_big.png"
+				pixbuf = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"busy.svg"
 				       	, MEMBER_PROTRAIT_SIZED , MEMBER_PROTRAIT_SIZED , NULL);
 				break;
 			default:
-				pixbuf = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"away_big.png"
+				pixbuf = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"away.svg"
 				       	, MEMBER_PROTRAIT_SIZED , MEMBER_PROTRAIT_SIZED , NULL);
 				break;
 		    }
@@ -478,20 +484,24 @@ static gboolean pggroup_on_key_pressed(GtkWidget* UNUSED(widget)
 		, GdkEventKey* event , gpointer data)
 {
 
-    	FxPGGroup *fxpg;
+	FxPGGroup *fxpg;
 	Config *config = NULL;
 
 	DEBUG_FOOTPRINT();
 
-	if(event->keyval == GDK_Return)
+	if(event->keyval == GDK_Return || event->keyval == GDK_ISO_Enter || event->keyval == GDK_KP_Enter)
 	{
 		fxpg = (FxPGGroup*)data;
 		config = fxpg->fxmain->user->config;
 		if(config->sendMode == SEND_MODE_ENTER)
 		{
-			if(event->state & GDK_CONTROL_MASK){
+			if(event->state & GDK_CONTROL_MASK || event->state & GDK_SHIFT_MASK){
 				return FALSE;
 			}else{
+ 				if (gtk_im_context_filter_keypress (GTK_TEXT_VIEW(fxpg->sendView)->im_context, event)) {
+					GTK_TEXT_VIEW (fxpg->sendView)->need_im_reset = TRUE;
+ 					return TRUE;
+ 				}
 				pggroup_send_message(fxpg);
 				return TRUE;
 			}
@@ -538,8 +548,8 @@ void pggroup_on_sendsms_clicked(GtkWidget *widget , gpointer data)
     	FxPGGroup *fxpg = (FxPGGroup*)data;
 	GtkToggleButton *btn = GTK_TOGGLE_BUTTON(widget);
 	if(gtk_toggle_button_get_active(btn)){
-		add_information(fxpg , _("Group member who didn`t bind fetion number"
-			    " to mobile number can`t receive the group sms you send"));
+		add_information(fxpg , _("Group member who didn't bind fetion number"
+			    " to mobile number can't receive the group sms you send"));
 	}
 }
 
@@ -552,7 +562,7 @@ void pggroup_on_space_clicked(GtkWidget *UNUSED(widget) , gpointer data)
 	if(fork() == 0){
 		pgsid = fetion_sip_get_pgid_by_sipuri(fxpg->pggroup->pguri);
 		sprintf(text , "%s?GroupID=%s" , PGGROUP_SPACE_URI , pgsid);
-		execlp("firefox" , "firefox" , text , (char**)NULL);
+		execlp("xdg-open" , "xdg-open" , text , (char**)NULL);
 	}
 }
 static void *pggroup_update_portrait_thread(void *data)
@@ -571,11 +581,18 @@ static void *pggroup_update_portrait_thread(void *data)
 
 	if(gtk_tree_model_get_iter_first(model , &iter)){
 		do{
+			if(!fxpg || !fxpg->pggroup)
+				return NULL;
 			gtk_tree_model_get(model , &iter , M_SIPURI_COL , &sipuri , -1);
 			sid = fetion_sip_get_sid_by_sipuri(sipuri);
 			snprintf(path , 1023 , "%s/%s.jpg" , config->iconPath , sid);
 			pixbuf = gdk_pixbuf_new_from_file_at_size(path
 			       	, MEMBER_PROTRAIT_SIZED , MEMBER_PROTRAIT_SIZED , NULL);
+
+			if(!fxpg || !fxpg->pggroup)
+				return NULL;
+
+			g_static_mutex_lock(&pg_mutex);
 			if(pixbuf == NULL && fxpg->pggroup->hasImage == 0){
 			    snprintf(portraitPath , 255 , "/%s/getportrait.aspx" , config->portraitServerPath );
 			    fetion_user_download_portrait_with_uri(user , sipuri
@@ -584,6 +601,11 @@ static void *pggroup_update_portrait_thread(void *data)
 			    pixbuf = gdk_pixbuf_new_from_file_at_size(path
 				    , MEMBER_PROTRAIT_SIZED , MEMBER_PROTRAIT_SIZED , NULL);
 			}
+			g_static_mutex_unlock(&pg_mutex);
+
+			if(!fxpg || !fxpg->pggroup)
+				return NULL;
+
 			if(pixbuf != NULL){
 				gdk_threads_enter();
 				gtk_tree_store_set(GTK_TREE_STORE(model) , &iter
@@ -595,6 +617,8 @@ static void *pggroup_update_portrait_thread(void *data)
 			free(sid);
 
 		}while(gtk_tree_model_iter_next(model , &iter));
+		if(!fxpg)
+			return NULL;
 		fxpg->pggroup->hasImage = 1;
 	}
 	return NULL;
@@ -638,7 +662,7 @@ static gboolean on_show_tooltip(GtkWidget* widget
 	sprintf(iconpath , "%s/%s.jpg" , config->iconPath , sid);
 	pixbuf = gdk_pixbuf_new_from_file_at_size(iconpath , 80 , 80 , NULL);
 	if(pixbuf == NULL)
-	    pixbuf = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"online_big.png" , 80 , 80 , NULL);
+	    pixbuf = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"online.svg" , 80 , 80 , NULL);
 	gtk_tooltip_set_icon(tip , pixbuf);	
 	g_object_unref(pixbuf);
 	gtk_tree_view_set_tooltip_row(tree , tip , path);
@@ -710,5 +734,20 @@ static void pg_window_destroy(GtkWidget *UNUSED(widget) , gpointer data)
 
 	fx_list_remove_pg_by_sipuri(fxpg->fxmain->pglist , fxpg->pggroup->pguri);
 
-	free(fxpg);
+	fxpg->pggroup = NULL;
+}
+
+static gboolean key_press_func(GtkWidget *widget , GdkEventKey *event
+		, gpointer UNUSED(data))
+{
+	if(event->keyval == GDK_w){
+		if(event->state & GDK_CONTROL_MASK){
+			gtk_widget_destroy(widget);
+			return TRUE;
+		}else{
+			return FALSE;
+		}
+	}
+
+	return FALSE;
 }
