@@ -111,7 +111,7 @@ static void show_search(GtkEntry *entry , gpointer data)
 		return;
 
 	if(has_gb(text)){
-		fx_util_popup_warning(fxmain , _("Only allow English word here!"));
+		fx_util_popup_warning(fxmain , _("Only English words are allowed here!"));
 		return;
 	}
 
@@ -123,7 +123,7 @@ static void show_search(GtkEntry *entry , gpointer data)
 	fx_search_initialize(search , model , text , x , y);
 }
 
-static void on_search_button_clicked(GtkEntry *entry , void *UNUSED(pos)
+static void on_search_button_clicked(GtkEntry *entry , GtkEntryIconPosition *UNUSED(pos)
 		, GdkEvent *UNUSED(event) , gpointer data)
 {
 	show_search(entry , data);
@@ -200,7 +200,7 @@ static gboolean pg_on_show_tooltip(GtkWidget* widget
 		return FALSE;
 	}
 
-	pixbuf = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"online_big.png" , 90 , 90 , NULL);
+	pixbuf = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"online.svg" , 90 , 90 , NULL);
 	gtk_tooltip_set_icon(tip , pixbuf);
 	g_object_unref(pixbuf);	
 
@@ -271,10 +271,10 @@ void fx_tree_bind_pg_data(FxMain *fxmain)
 			pixbuf = gdk_pixbuf_new_from_file_at_size(portraitPath , PG_PORTRAIT_SIZE , PG_PORTRAIT_SIZE , NULL);
 			if(pixbuf == NULL){
 			    if(pgcur->identity == 1)
-				pixbuf = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"online_big.png"
+				pixbuf = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"online.svg"
 				       	, PG_PORTRAIT_SIZE , PG_PORTRAIT_SIZE , NULL);
 			    else
-				pixbuf = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"invisible_big.png"
+				pixbuf = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"invisible.svg"
 				       	, PG_PORTRAIT_SIZE , PG_PORTRAIT_SIZE , NULL);
 			}
 			gtk_tree_store_set(store , &iter
@@ -302,16 +302,22 @@ void fx_tree_initilize(FxMain* fxmain)
 	ThreadArgs* args = (ThreadArgs*)malloc(sizeof(ThreadArgs));
 	args->fxmain = fxmain;
 	args->sip = NULL;
+	GValue value = { 0, };
 
 	DEBUG_FOOTPRINT();
 
+	all_light = fxmain->user->config->allHighlight;
 	fxtree = fxmain->mainPanel;
 
 	fxtree->searchbox = gtk_entry_new();
-#ifdef gtk_entry_set_icon_from_stock
+	g_value_init(&value, G_TYPE_STRING);
+	g_value_set_static_string(&value, "gtk-im-context-simple");
+	g_object_set_property(G_OBJECT(fxtree->searchbox),
+						"im-module",
+						&value);
+	g_value_unset (&value);
 	gtk_entry_set_icon_from_stock(GTK_ENTRY(fxtree->searchbox)
 			, GTK_ENTRY_ICON_SECONDARY , GTK_STOCK_FIND);
-#endif
 	g_signal_connect(fxtree->searchbox , "icon-press" , G_CALLBACK(on_search_button_clicked) , fxmain);
 	g_signal_connect(fxtree->searchbox , "activate" , G_CALLBACK(show_search) , fxmain);
 	gtk_widget_show_all(fxtree->searchbox);
@@ -390,12 +396,18 @@ void fx_tree_initilize(FxMain* fxmain)
 	fetion_contact_subscribe_only(fxmain->user);
 	g_thread_create(fx_tree_update_portrait_thread_func , fxmain , FALSE , NULL);
 	g_thread_create(fx_main_listen_thread_func , args , FALSE , NULL);
+}
+
+void fx_tree_show(FxMain *fxmain)
+{
+	FxTree *fxtree = fxmain->mainPanel;
 	gtk_widget_show_all(fxtree->scrollWindow);
 	gtk_widget_show_all(fxtree->pgScrollWindow);
 	gtk_widget_show_all(fxtree->noLabelScrollWindow);
 	gtk_widget_hide(fxtree->pgScrollWindow);
 	gtk_widget_hide(fxtree->noLabelScrollWindow);
 }
+
 void fx_tree_free(FxTree* fxtree)
 {
 	DEBUG_FOOTPRINT();
@@ -459,17 +471,17 @@ static GtkTreeModel* create_model(User* user)
 						 , G_ONLINE_COUNT_COL , 0 , -1);
 	}
 	foreach_contactlist(user->contactList , contact){
-		pb = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"fetion.png"
+		pb = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"fetion.svg"
 				, config->iconSize , config->iconSize , NULL);
 		if(fx_tree_get_group_iter_by_id(GTK_TREE_MODEL(store) , contact->groupid , &iter ) < 0){
-			debug_info("Error when a group iter not found , groupId :%s\n" , contact->groupid);
+			//debug_info("Error when a group iter not found , groupId :%d\n" , contact->groupid);
 			continue;
 		}
 		if(contact->state > 0)
 			gtk_tree_store_prepend(store , &iter1 , &iter);
 		else
 			gtk_tree_store_append(store , &iter1 , &iter);
-		name = (contact->nickname == NULL || strlen(contact->localname) == 0) ? contact->nickname : contact->localname;
+		name = (contact->localname == NULL || strlen(contact->localname) == 0) ? contact->nickname : contact->localname;
 
 		gtk_tree_store_set(store , &iter1
 						 , B_PIXBUF_COL 	, pb
@@ -540,12 +552,21 @@ int fx_tree_get_buddy_iter_by_userid(GtkTreeModel* model , const char* userid ,
 	}
 	return -1;
 }
-static void fx_tree_on_hightlight_clicked(GtkWidget *UNUSED(widget) , gpointer UNUSED(data))
+static void fx_tree_on_hightlight_clicked(GtkWidget *UNUSED(widget) , gpointer data)
 {
-	if(all_light)
+	FxMain *fxmain = (FxMain*)data;
+	User *user = fxmain->user;
+	Config *config = user->config;
+
+	if(all_light){
 		all_light = 0;
-	else
+		config->allHighlight = 0;
+	}else{
 		all_light = 1;
+		config->allHighlight = 1;
+	}
+
+	fetion_config_save(user);
 }
 static void fx_tree_create_buddy_menu(FxMain* fxmain , GtkWidget* UNUSED(tree)
 		, GtkTreePath* path , GdkEventButton* event , GtkTreeIter iter)
@@ -561,6 +582,8 @@ static void fx_tree_create_buddy_menu(FxMain* fxmain , GtkWidget* UNUSED(tree)
 	GtkTreeIter groupiter;
 	Args *profileargs , *moveargs , *chatargs;
 	FxTree* fxtree = fxmain->mainPanel;
+	User *user = fxmain->user;
+	Config *config = user->config;
 
 	DEBUG_FOOTPRINT();
 
@@ -608,10 +631,10 @@ static void fx_tree_create_buddy_menu(FxMain* fxmain , GtkWidget* UNUSED(tree)
 		fx_tree_create_menu(_("Edit note name") , SKIN_DIR"edit.png"
 						, menu , TRUE , fx_tree_on_editmenu_clicked , profileargs);
 
-		fx_tree_create_menu( !all_light ? _("Hightlight all contacts") : _("Hightlight online contacts") , SKIN_DIR"hilight.png"
-						, menu , TRUE , fx_tree_on_hightlight_clicked , NULL);
+		fx_tree_create_menu( config->allHighlight ? _("Hightlight online contacts") : _("Hightlight all contacts") , SKIN_DIR"hilight.png"
+						, menu , TRUE , fx_tree_on_hightlight_clicked , fxmain);
 
-		fx_tree_create_menu(iconsize > 30 ? _("Use little icon") : _("Use big icon")
+		fx_tree_create_menu(iconsize > 30 ? _("Use small icon") : _("Use big icon")
 						, SKIN_DIR"bigimage.png" , menu , TRUE , fx_tree_on_iconchange_clicked , fxmain);
 
 		fx_tree_create_menu(_("Remove this contact") , SKIN_DIR"delete.png"
@@ -633,7 +656,7 @@ static void fx_tree_create_buddy_menu(FxMain* fxmain , GtkWidget* UNUSED(tree)
 								 , G_NAME_COL 			 , &groupname
 								 , G_ID_COL 			 , &groupid , -1);
 				moveargs = fx_args_new(fxmain , iter , userid , groupid);
-				fx_tree_create_menu(groupname 	  , SKIN_DIR"user_invisible.png"
+				fx_tree_create_menu(groupname 	  , SKIN_DIR"online.svg"
 								  , groupSubmenu , TRUE , fx_tree_on_movemenu_clicked
 								  , moveargs);
 				free(groupname);
@@ -723,7 +746,7 @@ static void fx_tree_add_new_buddy(FxMain* fxmain , Contact* contact)
 						 , -1);
 		if(groupid == contact->groupid)
 		{
-			pb = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"fetion.png" , config->iconSize , config->iconSize , NULL);
+			pb = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"fetion.svg" , config->iconSize , config->iconSize , NULL);
 			gtk_tree_store_append(GTK_TREE_STORE(model) , &nIter , &oIter);
 			gtk_tree_store_set(GTK_TREE_STORE(model), &nIter
 							, B_PIXBUF_COL		, pb
@@ -828,6 +851,7 @@ static void fx_tree_text_cell_data_func(GtkTreeViewColumn *UNUSED(col),
 		sid = fetion_sip_get_sid_by_sipuri(sipuri);
 		bzero(stateStr1 , sizeof(stateStr1));
 		snprintf(stateStr1 , 255 , "<span color='#0099FF'>%s</span>" , stateStr);
+		escape_impression(impression);
 		if( size < 30)
 		{
 			snprintf(text , 1023 , "<b>%s</b>%s%s"
@@ -1017,9 +1041,11 @@ static void* fx_tree_update_portrait_thread_func(void* data)
 				pb = gdk_pixbuf_new_from_file_at_size(portraitPath
 				       	, PG_PORTRAIT_SIZE , PG_PORTRAIT_SIZE , NULL);
 				if(pb != NULL){
+					gdk_threads_enter();
 					gtk_tree_store_set(GTK_TREE_STORE(model) , &iter
 						, PG_PIXBUF_COL , pb , -1);
 					g_object_unref(pb);
+					gdk_threads_leave();
 				}
 			}else{
 				g_object_unref(pb);
@@ -1058,7 +1084,7 @@ static void fx_tree_on_double_click(GtkTreeView *treeview
 						 , -1);
 		if(relationStatus == RELATION_STATUS_UNAUTHENTICATED)
 		{
-			fx_util_popup_warning(fxmain , _("People not in your contact list ,to whom you can not send a message"));
+			fx_util_popup_warning(fxmain , _("You can not send a message to anyone who has not been in your contact list"));
 			return;
 		}
 		if(serviceStatus == BASIC_SERVICE_ABNORMAL && 
@@ -1128,20 +1154,37 @@ static void fx_tree_on_chatmenu_clicked(GtkWidget* UNUSED(widget) , gpointer dat
 	free(args);
 }
 
-static void fx_tree_on_profilemenu_clicked(GtkWidget* UNUSED(widget) , gpointer data)
+static void* on_profile_thread(void *data)
 {
 	Args* args = (Args*)data;
 	FxMain* fxmain = args->fxmain;
+	Contact *contact;
 	char* userid = args->s;
 	FxProfile* fxprofile = fx_profile_new(fxmain , userid);
 
 	DEBUG_FOOTPRINT();
 
+	gdk_threads_enter();
 	fx_profile_initialize(fxprofile);
+	gdk_threads_leave();
+
+	contact = fx_profile_fetch(fxprofile);
+
+	gdk_threads_enter();
+	if(contact)
+		fx_profile_bind(fxprofile , contact);
 	gtk_dialog_run(GTK_DIALOG(fxprofile->dialog));
 	gtk_widget_destroy(fxprofile->dialog);
+	gdk_threads_leave();
+
 	free(fxprofile);
 	free(args);
+	return NULL;
+}
+
+static void fx_tree_on_profilemenu_clicked(GtkWidget* UNUSED(widget) , gpointer data)
+{
+	g_thread_create(on_profile_thread , data , FALSE , NULL);
 }
 
 static void fx_tree_on_historymenu_clicked(GtkWidget* UNUSED(widget) , gpointer data)
@@ -1249,9 +1292,9 @@ static void* fx_tree_reload_thread(void* data)
 	snprintf(portraitPath , 1023 , "%s/%s.jpg" , config->iconPath , sid);
 	pb = gdk_pixbuf_new_from_file_at_size(portraitPath , 25 , 25 , NULL);
 	if(pb == NULL)
-		pb = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"fetion.png" , 25 , 25 , NULL);
+		pb = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"fetion.svg" , 25 , 25 , NULL);
 
-	name = (contact->nickname == NULL || strlen(contact->localname) == 0)
+	name = (contact->localname == NULL || strlen(contact->localname) == 0)
 			? contact->nickname : contact->localname;
 	gtk_tree_store_set(GTK_TREE_STORE(model) , &iter
 					 , B_PIXBUF_COL 	, pb
@@ -1328,7 +1371,7 @@ static void fx_tree_on_iconchange_clicked(GtkWidget* UNUSED(widget) , gpointer d
 					free(sid);
 					pb = gdk_pixbuf_new_from_file(path , NULL);
 					if(pb == NULL)
-						pb = gdk_pixbuf_new_from_file(SKIN_DIR"fetion.png" , NULL);
+						pb = gdk_pixbuf_new_from_file(SKIN_DIR"fetion.svg" , NULL);
 				}
 				pb = gdk_pixbuf_scale_simple(pb , config->iconSize , config->iconSize , GDK_INTERP_NEAREST);
 				gtk_tree_store_set(GTK_TREE_STORE(model) , &pointer
@@ -1590,7 +1633,7 @@ static gboolean fx_tree_on_show_tooltip(GtkWidget* widget
 	free(sid);
 	pb = gdk_pixbuf_new_from_file_at_size(iconpath , 80 , 80 , NULL);
 	if(pb == NULL)
-		pb = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"fetion.png" , 80 , 80 , NULL);
+		pb = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"fetion.svg" , 80 , 80 , NULL);
 	gtk_tooltip_set_markup(tip , text);
 	gtk_tooltip_set_icon(tip , pb);	
 	g_object_unref(pb);
@@ -1657,6 +1700,8 @@ static gboolean pg_on_rightbutton_click(GtkWidget* UNUSED(tree)
 		model = gtk_tree_view_get_model(GTK_TREE_VIEW(fxtree->pgTreeView));
 		gtk_tree_view_get_path_at_pos(GTK_TREE_VIEW(fxtree->pgTreeView) 
 				, (gint)event->x , (gint)event->y , &path , NULL , NULL , NULL);
+		if(!path)
+			return FALSE;
 
 		gtk_tree_model_get_iter(GTK_TREE_MODEL(model) , &iter , path);
 		gtk_tree_model_get(model , &iter
